/*
 *  Logo.scala
 *  (Mellite)
 *
 *  Copyright (c) 2012-2022 Hanns Holger Rutz. All rights reserved.
 *
 *  This software is published under the GNU Affero General Public License v3+
 *
 *
 *  For further information, please contact Hanns Holger Rutz at
 *  contact@sciss.de
 */

package de.sciss.mellite

import java.awt.geom.Path2D
import java.awt.{Color, Component, Graphics, RenderingHints}

import javax.swing.Icon

import scala.swing.Graphics2D

object Logo {
  def icon(size: Int = 256): Icon = new Icon {
    val getIconWidth : Int = (size * 192 / 256 + 0.5).toInt
    val getIconHeight: Int = size

    def paintIcon(c: Component, g: Graphics, x: Int, y: Int): Unit = {
      val g2 = g.asInstanceOf[Graphics2D]
      val atOrig = g2.getTransform
      if (getIconHeight != 256) {
        val scale = getIconHeight.toDouble / 256
        g2.scale(scale, scale)
      }
      g2.translate(x, y)
      g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING  , RenderingHints.VALUE_ANTIALIAS_ON)
      g2.setRenderingHint(RenderingHints.KEY_STROKE_CONTROL, RenderingHints.VALUE_STROKE_PURE )
      Logo.paint(g2)
      g2.setTransform(atOrig)
    }
  }

  /** Paints the logo onto a graphics context.
    * The size is 192 x 256 locates at (0, 0).
    * If a different size or offset is required,
    * the context must be transformed before.
    */
  def paint(g: Graphics2D): Unit = {
    val p = new Path2D.Float(Path2D.WIND_NON_ZERO, 272)
    mkPath1(p)
    g.setColor(Color.white)
    g.fill(p)

    p.reset()
    mkPath2(p)
    g.setColor(new Color(0xffe22d))
    g.fill(p)

    p.reset()
    mkPath3(p)
    g.setColor(new Color(0xada693))
    g.fill(p)

    p.reset()
    mkPath4(p)
    g.setColor(new Color(0x8f7026))
    g.fill(p)

    p.reset()
    mkPath5(p)
    g.setColor(new Color(0x1968ff))
    g.fill(p)

    p.reset()
    mkPath6(p)
    g.setColor(new Color(0x614f24))
    g.fill(p)

    p.reset()
    mkPath7(p)
    g.setColor(new Color(0x483815))
    g.fill(p)

    p.reset()
    mkPath8(p)
    g.setColor(Color.black)
    g.fill(p)

    //    val it = p.getPathIterator(AffineTransform.getTranslateInstance(0, 0))
    //    var i = 0
    //    while (!it.isDone) {
    //      i += 1
    //      it.next()
    //    }
    //    println(s"Max size = $i")
  }

  private def mkPath1(p: Path2D): Unit = {
    p.moveTo(149.10323f, 3.115529f)
    p.curveTo(111.208405f, 3.251529f, 73.31347f, 3.341969f, 35.418495f, 3.416479f)
    p.curveTo(24.545029f, 15.040049f, 13.49509f, 26.49338f, 2.492315f, 37.9918f)
    p.curveTo(3.067388f, 96.70656f, 2.329339f, 155.45018f, 3.949811f, 214.14532f)
    p.curveTo(3.574818f, 227.89702f, 16.6263f, 235.97562f, 24.785385f, 244.94223f)
    p.curveTo(27.865013f, 248.86333f, 32.078323f, 250.83034f, 37.00848f, 250.62663f)
    p.curveTo(73.59383f, 254.64633f, 110.92207f, 255.07784f, 147.57947f, 251.79703f)
    p.curveTo(161.65167f, 251.21413f, 169.19824f, 237.54733f, 177.69003f, 228.15602f)
    p.curveTo(185.15816f, 220.25122f, 187.94269f, 209.78181f, 188.72809f, 199.13037f)
    p.curveTo(191.01201f, 173.13802f, 189.73885f, 146.9038f, 190.26399f, 120.81876f)
    p.curveTo(189.81369f, 92.939064f, 191.21675f, 64.909615f, 189.05186f, 37.122406f)
    p.curveTo(179.90651f, 24.457245f, 167.69955f, 14.278927f, 156.88757f, 2.881466f)
    p.curveTo(154.29279f, 2.959466f, 151.698f, 3.0375059f, 149.10321f, 3.115536f)
    p.lineTo(149.10323f, 3.115529f)
  }

  private def mkPath2(p: Path2D): Unit = {
    p.moveTo(37.151894f, 255.15382f)
    p.curveTo(31.322405f, 254.07663f, 27.044113f, 250.88193f, 15.361536f, 238.88213f)
    p.curveTo(6.3876f, 229.66452f, 4.296521f, 226.86963f, 2.6979742f, 221.95622f)
    p.curveTo(0.92696f, 216.51282f, 0.7538645f, 209.34592f, 0.3916273f, 126.46407f)
    p.lineTo(-4.2876E-7f, 36.857067f)
    p.lineTo(10.405198f, 26.004068f)
    p.curveTo(16.128057f, 20.034908f, 23.80539f, 11.969169f, 27.465935f, 8.080179f)
    p.lineTo(34.12147f, 1.0093093f)
    p.lineTo(53.96587f, 0.26608932f)
    p.curveTo(64.880295f, -0.14269069f, 80.965256f, -0.07259068f, 89.710236f, 0.4218493f)
    p.curveTo(98.455215f, 0.9162893f, 117.19014f, 1.0563493f, 131.3434f, 0.7330793f)
    p.lineTo(157.07658f, 0.1453293f)
    p.lineTo(172.9166f, 16.007689f)
    p.curveTo(181.62862f, 24.73198f, 189.50119f, 33.45395f, 190.4112f, 35.38984f)
    p.curveTo(191.87532f, 38.5044f, 192.02081f, 47.93736f, 191.67514f, 117.32507f)
    p.curveTo(191.42921f, 166.68973f, 190.83937f, 199.42326f, 190.08302f, 205.68121f)
    p.curveTo(188.24652f, 220.87622f, 185.30489f, 226.23372f, 169.77805f, 242.66162f)
    p.curveTo(159.21843f, 253.83412f, 158.0343f, 254.25282f, 134.23012f, 255.23302f)
    p.curveTo(110.395584f, 256.21432f, 42.592445f, 256.15903f, 37.15188f, 255.15402f)
    p.lineTo(37.151894f, 255.15382f)
    p.moveTo(37.163834f, 183.67621f)
    p.curveTo(37.205925f, 182.926f, 36.047863f, 181.85449f, 34.590366f, 181.29512f)
    p.curveTo(33.075996f, 180.71391f, 31.940372f, 179.42604f, 31.940372f, 178.28986f)
    p.curveTo(31.940372f, 175.05635f, 30.667948f, 174.70335f, 28.029982f, 177.20505f)
    p.curveTo(26.118265f, 179.01802f, 25.264965f, 179.26466f, 24.294352f, 178.28487f)
    p.curveTo(22.34796f, 176.32005f, 21.340397f, 176.7695f, 21.340397f, 179.60255f)
    p.curveTo(21.340397f, 183.71272f, 22.35698f, 185.38634f, 24.508554f, 184.81837f)
    p.curveTo(25.92103f, 184.44551f, 26.969112f, 185.25319f, 28.206028f, 187.66776f)
    p.lineTo(29.932259f, 191.0375f)
    p.lineTo(33.50978f, 188.03886f)
    p.curveTo(35.477417f, 186.38962f, 37.12174f, 184.4264f, 37.163834f, 183.67621f)
    p.lineTo(37.163834f, 183.67621f)
    p.moveTo(64.3327f, 186.14427f)
    p.curveTo(66.34993f, 184.60408f, 66.34606f, 184.57259f, 64.13509f, 184.53923f)
    p.curveTo(62.89473f, 184.52052f, 61.28608f, 185.22746f, 60.56031f, 186.11024f)
    p.curveTo(58.759148f, 188.30106f, 61.47583f, 188.32556f, 64.3327f, 186.14424f)
    p.lineTo(64.3327f, 186.14427f)
    p.moveTo(173.13205f, 178.94106f)
    p.curveTo(172.12253f, 177.92198f, 171.44644f, 178.04408f, 169.99748f, 179.50713f)
    p.curveTo(168.38228f, 181.13802f, 168.34993f, 181.4973f, 169.74004f, 182.36514f)
    p.curveTo(172.00049f, 183.77634f, 174.96124f, 180.78757f, 173.13203f, 178.94106f)
    p.lineTo(173.13205f, 178.94106f)
    p.moveTo(147.57948f, 179.01416f)
    p.curveTo(149.20293f, 176.71265f, 149.6405f, 175.17877f, 148.97665f, 174.1164f)
    p.curveTo(147.63113f, 171.9631f, 146.15419f, 172.08908f, 144.91109f, 174.46318f)
    p.curveTo(144.33028f, 175.5724f, 142.98692f, 177.80412f, 141.92587f, 179.42255f)
    p.curveTo(139.99796f, 182.36316f, 139.9984f, 182.36513f, 142.60622f, 182.36513f)
    p.curveTo(144.32022f, 182.36513f, 146.02692f, 181.21516f, 147.57948f, 179.01416f)
    p.lineTo(147.57948f, 179.01416f)
    p.moveTo(167.62006f, 52.35663f)
    p.lineTo(170.27005f, 50.827408f)
    p.lineTo(167.62006f, 50.823406f)
    p.curveTo(166.16255f, 50.821407f, 164.04414f, 51.526485f, 162.91246f, 52.390537f)
    p.curveTo(160.87567f, 53.945667f, 160.87567f, 53.961166f, 162.91246f, 53.923637f)
    p.curveTo(164.04414f, 53.902737f, 166.16255f, 53.197536f, 167.62006f, 52.356476f)
    p.lineTo(167.62006f, 52.35663f)
    p.moveTo(150.06708f, 49.09345f)
    p.curveTo(151.32707f, 47.15226f, 151.83786f, 44.031387f, 151.83786f, 38.27427f)
    p.curveTo(151.83786f, 33.82421f, 151.59644f, 29.939518f, 151.30135f, 29.64164f)
    p.curveTo(151.00626f, 29.34375f, 148.59206f, 28.85281f, 145.93646f, 28.55066f)
    p.curveTo(141.78737f, 28.07857f, 140.7323f, 28.380629f, 138.4369f, 30.69777f)
    p.curveTo(136.04117f, 33.116158f, 133.59833f, 34.41934f, 128.2797f, 36.11631f)
    p.curveTo(127.09151f, 36.49542f, 126.56925f, 37.93312f, 126.56925f, 40.825012f)
    p.curveTo(126.56925f, 44.699112f, 126.76148f, 44.961113f, 129.33969f, 44.600983f)
    p.curveTo(131.54135f, 44.293453f, 132.49176f, 44.90428f, 133.96895f, 47.57619f)
    p.curveTo(135.6947f, 50.697742f, 136.12318f, 50.888012f, 139.95515f, 50.23447f)
    p.curveTo(142.489f, 49.80233f, 144.35335f, 49.97284f, 144.7839f, 50.67608f)
    p.curveTo(145.97426f, 52.62037f, 148.21318f, 51.94968f, 150.0671f, 49.09345f)
    p.lineTo(150.06708f, 49.09345f)
    p.moveTo(79.83413f, 43.45317f)
    p.curveTo(80.23226f, 43.053432f, 79.86275f, 39.70737f, 79.01308f, 36.01748f)
    p.curveTo(77.47731f, 29.34838f, 78.15117f, 25.070879f, 80.73756f, 25.070879f)
    p.curveTo(82.99523f, 25.070879f, 81.547424f, 21.780588f, 78.0503f, 18.963829f)
    p.curveTo(76.00983f, 17.320318f, 74.34033f, 15.132979f, 74.34031f, 14.103079f)
    p.curveTo(74.34029f, 13.073179f, 73.62478f, 12.230529f, 72.75028f, 12.230529f)
    p.curveTo(70.83897f, 12.230529f, 70.78124f, 12.716899f, 72.38489f, 15.309059f)
    p.curveTo(73.36787f, 16.89794f, 73.13527f, 18.277409f, 71.20613f, 22.300219f)
    p.curveTo(67.75564f, 29.495438f, 67.83025f, 40.6977f, 71.347145f, 43.46922f)
    p.curveTo(73.68638f, 45.31268f, 77.99026f, 45.304527f, 79.83413f, 43.45322f)
    p.lineTo(79.83413f, 43.45317f)
    p.moveTo(51.020332f, 42.78952f)
    p.curveTo(51.020332f, 41.18322f, 49.117283f, 39.47561f, 48.274864f, 40.32601f)
    p.curveTo(47.53554f, 41.072323f, 48.999237f, 44.331413f, 50.073742f, 44.331413f)
    p.curveTo(50.594364f, 44.331413f, 51.020332f, 43.63756f, 51.020332f, 42.789524f)
    p.lineTo(51.020332f, 42.78952f)
    p.moveTo(43.92123f, 21.058239f)
    p.curveTo(44.16653f, 20.61685f, 44.67396f, 18.958939f, 45.048855f, 17.37398f)
    p.curveTo(45.620277f, 14.95813f, 45.25839f, 14.259239f, 42.810413f, 13.051069f)
    p.curveTo(41.007664f, 12.161339f, 40.010773f, 10.904299f, 40.205074f, 9.765829f)
    p.curveTo(40.618275f, 7.3447294f, 37.667812f, 6.260199f, 35.53319f, 8.048549f)
    p.curveTo(31.974104f, 11.030279f, 36.73324f, 21.86076f, 41.602562f, 21.86076f)
    p.curveTo(42.632526f, 21.86076f, 43.675926f, 21.49963f, 43.92123f, 21.058239f)
    p.lineTo(43.92123f, 21.058239f)
  }

  private def mkPath3(p: Path2D): Unit = {
    p.moveTo(84.22588f, 255.02112f)
    p.curveTo(82.141495f, 254.41202f, 79.99142f, 252.61682f, 78.57444f, 250.30252f)
    p.curveTo(75.95646f, 246.02643f, 74.19721f, 245.68352f, 70.38952f, 248.70702f)
    p.curveTo(68.4505f, 250.24661f, 66.08934f, 250.84702f, 61.9733f, 250.84702f)
    p.curveTo(54.748825f, 250.84702f, 50.329967f, 248.95181f, 46.075787f, 244.02872f)
    p.curveTo(44.23079f, 241.89352f, 42.233818f, 240.14671f, 41.638073f, 240.14671f)
    p.curveTo(41.042328f, 240.14671f, 39.212875f, 242.67471f, 37.572628f, 245.76442f)
    p.curveTo(35.205704f, 250.22292f, 33.976715f, 251.45312f, 31.616339f, 251.72643f)
    p.curveTo(29.05983f, 252.02232f, 26.951105f, 250.36992f, 16.595535f, 239.95602f)
    p.curveTo(6.208913f, 229.51082f, 4.2892904f, 227.03032f, 2.6660032f, 221.95622f)
    p.curveTo(0.9375353f, 216.55333f, 0.7511622f, 208.72823f, 0.39162374f, 126.46407f)
    p.lineTo(-4.2876E-7f, 36.857067f)
    p.lineTo(10.405198f, 26.004068f)
    p.curveTo(16.128057f, 20.034908f, 23.807152f, 11.965988f, 27.469856f, 8.073128f)
    p.lineTo(34.129314f, 0.99518776f)
    p.lineTo(52.3798f, 0.6606778f)
    p.curveTo(62.893112f, 0.4679778f, 70.18091f, 0.7235778f, 69.57028f, 1.2637078f)
    p.curveTo(68.98728f, 1.7793577f, 65.66591f, 3.0702477f, 62.189453f, 4.1323376f)
    p.curveTo(55.870567f, 6.0628176f, 55.869343f, 6.0640078f, 58.214462f, 7.9809275f)
    p.curveTo(61.23576f, 10.450587f, 61.221626f, 12.474577f, 58.186142f, 12.037407f)
    p.curveTo(56.808422f, 11.838997f, 55.648335f, 10.797287f, 55.42208f, 9.555428f)
    p.curveTo(54.609146f, 5.0933475f, 53.093098f, 4.4350076f, 45.045456f, 5.0494075f)
    p.curveTo(35.35904f, 5.7889175f, 33.00037f, 7.0223975f, 33.00037f, 11.348417f)
    p.curveTo(33.00037f, 13.175938f, 31.981537f, 16.890717f, 30.736296f, 19.603497f)
    p.curveTo(29.491055f, 22.316286f, 27.974297f, 25.628967f, 27.365723f, 26.965027f)
    p.curveTo(26.14707f, 29.640427f, 27.015142f, 31.058367f, 30.236763f, 31.654667f)
    p.curveTo(31.340271f, 31.858917f, 32.613327f, 32.748306f, 33.065777f, 33.631077f)
    p.curveTo(33.518227f, 34.513855f, 35.28988f, 38.08909f, 37.002792f, 41.576046f)
    p.curveTo(39.250244f, 46.151165f, 40.745193f, 47.962677f, 42.37329f, 48.083767f)
    p.curveTo(44.97127f, 48.276966f, 48.900333f, 51.52588f, 48.900333f, 53.48092f)
    p.curveTo(48.900333f, 54.21113f, 46.508278f, 56.358078f, 43.584652f, 58.25192f)
    p.curveTo(39.491158f, 60.90357f, 37.60236f, 61.52937f, 35.36967f, 60.973698f)
    p.curveTo(24.825651f, 58.349537f, 22.400394f, 59.306396f, 22.400394f, 66.09061f)
    p.curveTo(22.400394f, 68.600525f, 21.860626f, 71.19897f, 21.200907f, 71.86494f)
    p.curveTo(18.871437f, 74.216446f, 26.809578f, 76.383125f, 35.16401f, 75.67609f)
    p.curveTo(43.734737f, 74.950745f, 47.34048f, 72.79323f, 48.675823f, 67.59121f)
    p.curveTo(49.31434f, 65.10379f, 50.34671f, 64.02275f, 52.66384f, 63.41522f)
    p.curveTo(54.383404f, 62.96436f, 57.45842f, 61.188328f, 59.497208f, 59.46848f)
    p.lineTo(63.204094f, 56.341488f)
    p.lineTo(59.178005f, 53.943558f)
    p.curveTo(55.6748f, 51.85706f, 55.234894f, 51.164257f, 55.79082f, 48.609188f)
    p.curveTo(56.24705f, 46.51233f, 55.959473f, 45.49059f, 54.785027f, 45.03565f)
    p.curveTo(53.736755f, 44.629578f, 53.140327f, 43.054398f, 53.140327f, 40.69196f)
    p.curveTo(53.140327f, 37.92514f, 52.602825f, 36.81317f, 51.020332f, 36.30616f)
    p.curveTo(49.854336f, 35.93258f, 48.900337f, 34.68957f, 48.900337f, 33.5439f)
    p.curveTo(48.900337f, 31.334879f, 54.89623f, 25.15515f, 57.09088f, 25.10221f)
    p.curveTo(59.103653f, 25.05361f, 61.262943f, 29.222649f, 63.149765f, 36.80021f)
    p.curveTo(65.036545f, 44.37758f, 65.57666f, 44.98415f, 71.30747f, 45.961517f)
    p.curveTo(77.4498f, 47.00908f, 81.46737f, 44.36318f, 82.30201f, 38.720688f)
    p.curveTo(82.672554f, 36.215656f, 82.48961f, 32.87924f, 81.89545f, 31.306398f)
    p.curveTo(81.06373f, 29.10472f, 81.1678f, 28.15128f, 82.3477f, 27.162779f)
    p.curveTo(84.47246f, 25.382698f, 84.28407f, 24.202269f, 81.230255f, 20.160599f)
    p.curveTo(78.03614f, 15.933269f, 78.02595f, 15.836509f, 80.70026f, 15.1305485f)
    p.curveTo(82.46778f, 14.663948f, 82.82025f, 13.671008f, 82.82025f, 9.158228f)
    p.curveTo(82.82025f, 3.104948f, 81.145256f, 1.3320079f, 76.30823f, 2.265408f)
    p.curveTo(74.74717f, 2.566648f, 73.18578f, 2.241508f, 72.74634f, 1.523788f)
    p.curveTo(72.14429f, 0.540438f, 77.67521f, 0.38895798f, 96.73703f, 0.86674803f)
    p.curveTo(110.36224f, 1.208258f, 124.724266f, 1.4972479f, 128.65263f, 1.5089481f)
    p.curveTo(134.83786f, 1.527348f, 135.76128f, 1.7811681f, 135.54262f, 3.4027581f)
    p.curveTo(135.13522f, 6.423908f, 137.26883f, 6.582738f, 138.66818f, 3.6354282f)
    p.curveTo(139.87343f, 1.0969882f, 140.50505f, 0.9093983f, 148.65085f, 0.67075825f)
    p.lineTo(157.34686f, 0.41600823f)
    p.lineTo(173.05173f, 16.143028f)
    p.curveTo(181.6894f, 24.792889f, 189.48636f, 33.422447f, 190.37828f, 35.319847f)
    p.curveTo(191.78603f, 38.314537f, 191.99997f, 48.683746f, 191.99997f, 113.92161f)
    p.curveTo(191.99997f, 158.76888f, 191.57253f, 191.8201f, 190.93997f, 195.88464f)
    p.curveTo(190.35698f, 199.63074f, 189.38011f, 205.88593f, 188.76917f, 209.78513f)
    p.curveTo(187.45305f, 218.18492f, 183.90857f, 223.93182f, 170.85786f, 238.82602f)
    p.curveTo(159.0212f, 252.33463f, 157.48076f, 253.03322f, 135.8201f, 254.71672f)
    p.curveTo(115.57653f, 256.29f, 89.10339f, 256.44632f, 84.22586f, 255.02112f)
    p.lineTo(84.22588f, 255.02112f)
    p.moveTo(51.955208f, 226.09262f)
    p.curveTo(54.064518f, 224.83662f, 56.80315f, 222.61803f, 58.04106f, 221.16252f)
    p.curveTo(60.789383f, 217.93082f, 64.46745f, 218.63992f, 65.44976f, 222.59082f)
    p.curveTo(65.80968f, 224.03842f, 66.971924f, 225.69162f, 68.03253f, 226.26462f)
    p.curveTo(70.95239f, 227.84201f, 79.27029f, 227.52692f, 81.00768f, 225.77312f)
    p.curveTo(82.77513f, 223.98901f, 84.351814f, 215.54411f, 83.125275f, 214.43112f)
    p.curveTo(82.66601f, 214.01442f, 79.996796f, 213.37563f, 77.19368f, 213.01163f)
    p.curveTo(72.60546f, 212.41583f, 71.83546f, 212.63483f, 69.4739f, 215.20712f)
    p.curveTo(67.02242f, 217.87743f, 66.73467f, 217.94733f, 65.07872f, 216.27573f)
    p.curveTo(63.422764f, 214.60402f, 63.431057f, 214.39523f, 65.20543f, 213.08542f)
    p.curveTo(66.98111f, 211.77472f, 66.92649f, 211.60233f, 64.362206f, 210.42291f)
    p.curveTo(62.27489f, 209.46281f, 61.620308f, 208.37311f, 61.620308f, 205.85841f)
    p.curveTo(61.620308f, 204.04152f, 61.114025f, 201.60004f, 60.495235f, 200.43289f)
    p.curveTo(58.870026f, 197.36742f, 61.082752f, 191.02744f, 64.99072f, 187.55225f)
    p.curveTo(68.06981f, 184.81415f, 68.10327f, 184.68881f, 65.94011f, 183.99576f)
    p.curveTo(63.37964f, 183.17542f, 53.886505f, 186.05339f, 52.13809f, 188.18005f)
    p.curveTo(51.497124f, 188.95967f, 50.77713f, 191.58199f, 50.5381f, 194.0074f)
    p.curveTo(50.299072f, 196.43283f, 49.120064f, 199.81145f, 47.91808f, 201.51546f)
    p.curveTo(45.783268f, 204.54192f, 45.628178f, 204.58272f, 41.221508f, 203.27835f)
    p.curveTo(36.47426f, 201.87318f, 33.11948f, 197.83926f, 34.424843f, 195.10577f)
    p.curveTo(36.935802f, 189.84772f, 39.41688f, 186.93883f, 42.857056f, 185.21959f)
    p.curveTo(45.014862f, 184.14122f, 46.78034f, 182.79787f, 46.78034f, 182.23438f)
    p.curveTo(46.78034f, 180.69765f, 42.613434f, 172.75562f, 41.72381f, 172.59674f)
    p.curveTo(36.127285f, 171.59723f, 31.145788f, 172.09026f, 28.639585f, 173.89172f)
    p.curveTo(27.068531f, 175.021f, 24.811663f, 175.94495f, 23.62432f, 175.94495f)
    p.curveTo(20.507523f, 175.94495f, 19.964935f, 177.5098f, 20.784836f, 184.13416f)
    p.curveTo(21.304634f, 188.33385f, 22.212273f, 190.63474f, 23.951244f, 192.16107f)
    p.curveTo(25.62965f, 193.63423f, 26.614458f, 196.0165f, 27.112833f, 199.80899f)
    p.curveTo(27.510948f, 202.83853f, 28.199287f, 205.8108f, 28.642473f, 206.414f)
    p.curveTo(29.085659f, 207.0173f, 30.339851f, 210.6406f, 31.42957f, 214.466f)
    p.curveTo(34.307583f, 224.569f, 35.426598f, 225.9304f, 41.82231f, 227.11f)
    p.curveTo(44.840725f, 227.6666f, 47.492535f, 228.1793f, 47.715218f, 228.2493f)
    p.curveTo(47.937904f, 228.3193f, 49.845898f, 227.3487f, 51.955208f, 226.0926f)
    p.lineTo(51.955208f, 226.09262f)
    p.moveTo(151.23021f, 209.80652f)
    p.curveTo(151.04845f, 207.83232f, 150.3688f, 205.21571f, 149.71991f, 203.99171f)
    p.curveTo(149.07101f, 202.76776f, 148.54008f, 200.10837f, 148.54008f, 198.08194f)
    p.curveTo(148.54008f, 193.6955f, 150.71542f, 191.39894f, 153.50732f, 192.8379f)
    p.curveTo(154.56482f, 193.38297f, 158.34206f, 194.38988f, 161.90114f, 195.0755f)
    p.curveTo(167.02335f, 196.06223f, 169.23288f, 196.03226f, 172.50111f, 194.93169f)
    p.curveTo(176.41109f, 193.61502f, 176.61354f, 193.33012f, 176.31914f, 189.55826f)
    p.curveTo(176.14815f, 187.36758f, 176.38664f, 185.56786f, 176.84914f, 185.55885f)
    p.curveTo(177.31161f, 185.54985f, 178.33551f, 185.12955f, 179.12445f, 184.6249f)
    p.curveTo(180.28804f, 183.88058f, 180.3108f, 183.2394f, 179.24496f, 181.22905f)
    p.curveTo(178.52232f, 179.866f, 177.77579f, 176.51389f, 177.58603f, 173.77994f)
    p.curveTo(177.0747f, 166.4134f, 175.4383f, 162.69032f, 173.17027f, 163.73352f)
    p.curveTo(172.15813f, 164.19905f, 168.612f, 164.60915f, 165.28995f, 164.6448f)
    p.curveTo(158.29489f, 164.71991f, 156.23822f, 166.05075f, 157.99533f, 169.36499f)
    p.curveTo(158.96127f, 171.18695f, 158.80463f, 171.77078f, 157.10321f, 172.68996f)
    p.curveTo(154.28563f, 174.21216f, 151.58327f, 174.03712f, 149.14413f, 172.17444f)
    p.curveTo(147.33627f, 170.79385f, 146.8737f, 170.81711f, 145.16913f, 172.37431f)
    p.curveTo(144.10815f, 173.34358f, 143.24008f, 175.2068f, 143.24008f, 176.51482f)
    p.curveTo(143.24008f, 177.82285f, 142.52458f, 179.49246f, 141.65009f, 180.2251f)
    p.curveTo(139.2123f, 182.26744f, 139.74634f, 183.43518f, 143.11818f, 183.43518f)
    p.curveTo(145.21043f, 183.43518f, 146.72464f, 182.59033f, 147.9126f, 180.76012f)
    p.curveTo(148.86758f, 179.28883f, 150.35344f, 178.08505f, 151.2145f, 178.08505f)
    p.curveTo(153.23228f, 178.08505f, 153.24362f, 181.71477f, 151.2311f, 183.4008f)
    p.curveTo(150.37918f, 184.11452f, 149.37035f, 185.7384f, 148.98926f, 187.00943f)
    p.curveTo(148.60818f, 188.28044f, 147.33694f, 190.37918f, 146.1643f, 191.67328f)
    p.curveTo(144.56259f, 193.4409f, 144.22113f, 194.7718f, 144.79167f, 197.02342f)
    p.curveTo(145.20937f, 198.67189f, 145.63902f, 202.11914f, 145.74648f, 204.68394f)
    p.curveTo(145.89078f, 208.12885f, 146.58888f, 209.87625f, 148.41835f, 211.37164f)
    p.curveTo(151.63136f, 213.99805f, 151.6168f, 214.00615f, 151.23015f, 209.80655f)
    p.lineTo(151.23021f, 209.80652f)
    p.moveTo(70.33349f, 146.9657f)
    p.curveTo(71.74515f, 145.04948f, 72.25745f, 142.9169f, 72.0043f, 140.01051f)
    p.lineTo(71.639206f, 135.81888f)
    p.lineTo(70.110634f, 139.02896f)
    p.curveTo(69.26993f, 140.79451f, 67.492676f, 143.72903f, 66.16118f, 145.55014f)
    p.curveTo(64.82969f, 147.37125f, 63.74029f, 149.2104f, 63.74029f, 149.63718f)
    p.curveTo(63.74029f, 151.42586f, 68.45508f, 149.51549f, 70.33349f, 146.96571f)
    p.lineTo(70.33349f, 146.9657f)
    p.moveTo(53.14032f, 144.91412f)
    p.curveTo(53.14032f, 142.48868f, 52.041096f, 142.17165f, 50.172325f, 144.0581f)
    p.curveTo(48.303555f, 145.94455f, 48.61762f, 147.05418f, 51.020325f, 147.05418f)
    p.curveTo(52.433655f, 147.05418f, 53.14032f, 146.34082f, 53.14032f, 144.91412f)
    p.lineTo(53.14032f, 144.91412f)
    p.moveTo(169.74004f, 55.74389f)
    p.curveTo(170.61453f, 55.76139f, 172.04553f, 55.969547f, 172.92003f, 56.20628f)
    p.curveTo(174.17142f, 56.54505f, 174.49756f, 55.58196f, 174.45146f, 51.68397f)
    p.curveTo(174.40157f, 47.45884f, 173.7252f, 45.926193f, 169.84778f, 41.25119f)
    p.curveTo(167.26488f, 38.137f, 164.41977f, 35.77114f, 163.25766f, 35.77114f)
    p.curveTo(162.13292f, 35.77114f, 159.1961f, 33.903103f, 156.73138f, 31.61993f)
    p.curveTo(149.1631f, 24.60912f, 139.93933f, 24.98105f, 133.17012f, 32.569992f)
    p.curveTo(132.00412f, 33.877193f, 129.97688f, 35.361042f, 128.66513f, 35.867462f)
    p.curveTo(126.73794f, 36.611473f, 126.28014f, 37.614872f, 126.28014f, 41.09481f)
    p.curveTo(126.28014f, 44.80487f, 126.5998f, 45.40141f, 128.58794f, 45.40141f)
    p.curveTo(129.85724f, 45.40141f, 132.12297f, 46.8587f, 133.62292f, 48.63984f)
    p.curveTo(136.04535f, 51.51637f, 136.71422f, 51.76992f, 139.60811f, 50.90873f)
    p.curveTo(141.88332f, 50.23166f, 143.64081f, 50.35772f, 145.4343f, 51.32665f)
    p.curveTo(147.78255f, 52.595287f, 148.23433f, 52.433777f, 150.70958f, 49.44075f)
    p.curveTo(153.05661f, 46.6028f, 153.71745f, 46.32989f, 155.67793f, 47.38904f)
    p.curveTo(156.94725f, 48.07479f, 158.08632f, 49.89077f, 158.27461f, 51.528862f)
    p.curveTo(158.66272f, 54.90518f, 162.78049f, 57.501312f, 166.03004f, 56.418404f)
    p.curveTo(167.19604f, 56.029842f, 168.86554f, 55.726315f, 169.74004f, 55.743893f)
    p.lineTo(169.74004f, 55.74389f)
    p.moveTo(24.520388f, 22.93079f)
    p.curveTo(24.520388f, 21.75376f, 23.833042f, 20.79073f, 22.99295f, 20.79073f)
    p.curveTo(21.120369f, 20.79073f, 19.923138f, 22.55162f, 20.810398f, 24.00082f)
    p.curveTo(21.963135f, 25.88363f, 24.52039f, 25.14608f, 24.52039f, 22.93079f)
    p.lineTo(24.520388f, 22.93079f)
    p.moveTo(145.32281f, 9.090759f)
    p.curveTo(146.8363f, 6.2360096f, 146.69696f, 3.6702695f, 145.02843f, 3.6702695f)
    p.curveTo(143.6091f, 3.6702695f, 137.94012f, 9.06567f, 137.94012f, 10.4165f)
    p.curveTo(137.94012f, 12.19552f, 144.2804f, 11.05698f, 145.32281f, 9.09076f)
    p.lineTo(145.32281f, 9.090759f)
  }

  private def mkPath4(p: Path2D): Unit = {
    p.moveTo(97.13022f, 247.64882f)
    p.curveTo(86.73666f, 247.16132f, 84.90858f, 246.76862f, 80.29883f, 244.03352f)
    p.curveTo(75.47567f, 241.17172f, 74.853836f, 241.05623f, 71.06493f, 242.31862f)
    p.curveTo(65.39887f, 244.20622f, 52.503525f, 243.09412f, 46.9611f, 240.23982f)
    p.curveTo(41.57504f, 237.46602f, 38.10895f, 237.40422f, 35.746002f, 240.04002f)
    p.curveTo(34.74339f, 241.15842f, 32.990955f, 242.31952f, 31.851704f, 242.62022f)
    p.curveTo(27.286808f, 243.82532f, 6.275196f, 224.21162f, 3.3672123f, 216.03093f)
    p.curveTo(2.123828f, 212.53304f, 1.7915726f, 196.51784f, 1.4688596f, 124.52722f)
    p.lineTo(1.0776757f, 37.26347f)
    p.lineTo(18.364017f, 19.52143f)
    p.lineTo(35.65036f, 1.7793891f)
    p.lineTo(46.780334f, 2.0457692f)
    p.curveTo(52.90182f, 2.1922793f, 59.341305f, 2.4126792f, 61.0903f, 2.5355492f)
    p.lineTo(64.270294f, 2.7589493f)
    p.lineTo(60.03359f, 4.6455994f)
    p.curveTo(55.835632f, 6.5149794f, 55.818665f, 6.5459695f, 58.178593f, 8.033719f)
    p.curveTo(61.27374f, 9.984959f, 61.298843f, 12.487188f, 58.218754f, 12.037409f)
    p.curveTo(56.738388f, 11.8212385f, 55.64983f, 10.711649f, 55.25894f, 9.020409f)
    p.curveTo(54.330547f, 5.0035787f, 50.62091f, 3.8027987f, 42.081543f, 4.7550187f)
    p.curveTo(33.871765f, 5.670489f, 31.940369f, 7.2117486f, 31.940369f, 12.84771f)
    p.curveTo(31.940369f, 14.72777f, 31.227808f, 17.64519f, 30.356903f, 19.33088f)
    p.curveTo(29.485996f, 21.01657f, 28.770498f, 23.142118f, 28.766907f, 24.05432f)
    p.curveTo(28.763308f, 24.966518f, 28.220041f, 26.25832f, 27.55963f, 26.92498f)
    p.curveTo(25.84487f, 28.65597f, 27.24202f, 31.49103f, 29.809832f, 31.49103f)
    p.curveTo(31.203825f, 31.49103f, 32.39074f, 32.54851f, 33.112553f, 34.43361f)
    p.curveTo(33.732254f, 36.05203f, 34.914528f, 38.73937f, 35.739822f, 40.40548f)
    p.curveTo(38.027645f, 45.02416f, 37.603218f, 46.30574f, 33.530365f, 47.07705f)
    p.curveTo(29.389946f, 47.86115f, 28.776403f, 49.84082f, 31.470476f, 53.72355f)
    p.curveTo(33.45689f, 56.586388f, 34.7046f, 56.74854f, 35.360897f, 54.22915f)
    p.curveTo(35.629185f, 53.199238f, 37.645206f, 51.70441f, 39.840946f, 50.907288f)
    p.curveTo(43.20959f, 49.684387f, 44.060078f, 49.68702f, 45.28562f, 50.924187f)
    p.curveTo(46.51552f, 52.165726f, 45.929153f, 53.093716f, 41.45837f, 56.98121f)
    p.curveTo(36.44249f, 61.34267f, 36.06103f, 61.48885f, 33.823677f, 59.90691f)
    p.curveTo(31.035982f, 57.93586f, 27.737255f, 57.78316f, 24.098576f, 59.45674f)
    p.curveTo(21.031267f, 60.86753f, 19.733799f, 63.46817f, 21.305643f, 65.05489f)
    p.curveTo(22.758907f, 66.52191f, 22.700005f, 70.35168f, 21.200905f, 71.86496f)
    p.curveTo(19.027678f, 74.05876f, 26.649334f, 76.27871f, 35.295906f, 75.97041f)
    p.curveTo(44.941193f, 75.626495f, 45.879498f, 75.20906f, 48.80056f, 69.962555f)
    p.curveTo(51.44702f, 65.20924f, 51.358017f, 65.25849f, 54.13616f, 67.0099f)
    p.curveTo(57.152767f, 68.91164f, 61.658016f, 66.64372f, 60.8742f, 63.618023f)
    p.curveTo(60.552124f, 62.374752f, 61.00422f, 60.565514f, 61.89218f, 59.544132f)
    p.curveTo(62.770733f, 58.533592f, 63.80649f, 56.65552f, 64.19388f, 55.370693f)
    p.curveTo(64.80739f, 53.335823f, 64.44881f, 52.990894f, 61.412945f, 52.695614f)
    p.curveTo(57.495613f, 52.314606f, 56.518402f, 50.210445f, 58.79754f, 47.064045f)
    p.curveTo(60.12988f, 45.224716f, 60.613514f, 45.164043f, 63.68989f, 46.450386f)
    p.curveTo(66.42728f, 47.594986f, 67.01053f, 48.370037f, 66.63336f, 50.361774f)
    p.curveTo(66.30006f, 52.121834f, 66.89466f, 53.329674f, 68.673706f, 54.506374f)
    p.curveTo(70.60332f, 55.782673f, 71.03237f, 56.778633f, 70.52744f, 58.809456f)
    p.curveTo(69.62918f, 62.422325f, 71.326256f, 62.128204f, 74.22643f, 58.168377f)
    p.curveTo(76.755356f, 54.715458f, 76.58077f, 51.821606f, 73.843544f, 51.821606f)
    p.curveTo(70.86917f, 51.821606f, 72.170006f, 49.668655f, 76.195274f, 47.929367f)
    p.curveTo(82.875885f, 45.042717f, 83.34428f, 44.702946f, 83.52768f, 42.610508f)
    p.curveTo(83.62531f, 41.497196f, 84.31397f, 39.05378f, 85.05816f, 37.18068f)
    p.curveTo(86.30812f, 34.03455f, 86.21383f, 33.613438f, 83.82074f, 31.653929f)
    p.curveTo(83.82074f, 31.653929f, 82.37111f, 30.39968f, 82.30169f, 29.532799f)
    p.curveTo(82.227486f, 28.605549f, 83.54479f, 27.034328f, 83.54479f, 27.034328f)
    p.lineTo(85.85933f, 24.535868f)
    p.lineTo(82.77832f, 20.790768f)
    p.curveTo(79.296844f, 16.558887f, 78.963234f, 15.440618f, 81.182236f, 15.440618f)
    p.curveTo(83.02507f, 15.440618f, 84.41478f, 9.175938f, 83.44088f, 5.2588673f)
    p.curveTo(82.97445f, 3.3828573f, 83.25012f, 2.3665872f, 84.33999f, 1.9444172f)
    p.curveTo(85.20447f, 1.6095372f, 96.41695f, 1.8176672f, 109.25659f, 2.4069371f)
    p.curveTo(128.5401f, 3.291937f, 132.90475f, 3.784547f, 134.34508f, 5.238497f)
    p.curveTo(135.96333f, 6.872057f, 136.25558f, 6.8404665f, 138.40776f, 4.7994766f)
    p.curveTo(140.8741f, 2.4605267f, 143.24013f, 1.9043865f, 143.24013f, 3.6635866f)
    p.curveTo(143.24013f, 5.011307f, 134.90129f, 11.160497f, 133.07367f, 11.160497f)
    p.curveTo(132.32104f, 11.160497f, 131.41048f, 11.642016f, 131.05016f, 12.230527f)
    p.curveTo(130.64317f, 12.895267f, 132.6452f, 13.300557f, 136.33577f, 13.300557f)
    p.curveTo(141.29047f, 13.300557f, 142.72517f, 12.847627f, 144.97983f, 10.571637f)
    p.curveTo(146.98497f, 8.547507f, 147.51483f, 7.165737f, 147.03145f, 5.221497f)
    p.curveTo(146.60165f, 3.492867f, 146.8378f, 2.563297f, 147.72491f, 2.491717f)
    p.curveTo(148.46477f, 2.432017f, 150.92737f, 2.214157f, 153.19734f, 2.007617f)
    p.curveTo(157.1101f, 1.651597f, 157.78484f, 2.085817f, 166.18231f, 10.364977f)
    p.curveTo(175.27477f, 20.150597f, 179.09668f, 22.674257f, 186.17003f, 31.141857f)
    p.curveTo(186.17003f, 31.141857f, 189.32625f, 34.258408f, 190.05287f, 36.277836f)
    p.curveTo(192.59279f, 43.336807f, 191.03038f, 58.762615f, 191.03038f, 58.762615f)
    p.curveTo(191.3716f, 71.12926f, 191.47404f, 105.08232f, 191.25809f, 134.21385f)
    p.curveTo(190.8238f, 192.79532f, 189.83179f, 204.65762f, 184.7312f, 212.26053f)
    p.curveTo(179.52534f, 220.02032f, 163.31445f, 238.65443f, 160.1041f, 240.56873f)
    p.curveTo(154.54573f, 243.88333f, 141.40108f, 246.57733f, 127.9185f, 247.16542f)
    p.curveTo(120.89592f, 247.47173f, 113.71919f, 247.82892f, 111.97019f, 247.95912f)
    p.curveTo(110.2212f, 248.08932f, 103.54321f, 247.94812f, 97.130226f, 247.64882f)
    p.lineTo(97.13022f, 247.64882f)
    p.moveTo(51.955208f, 226.09262f)
    p.curveTo(54.064518f, 224.83662f, 56.80315f, 222.61803f, 58.04106f, 221.16252f)
    p.curveTo(60.789383f, 217.93082f, 64.46745f, 218.63992f, 65.44976f, 222.59082f)
    p.curveTo(66.316444f, 226.07661f, 68.85942f, 227.30643f, 75.20079f, 227.30643f)
    p.curveTo(81.12475f, 227.30643f, 81.84157f, 226.68823f, 84.194855f, 219.55113f)
    p.curveTo(85.832695f, 214.58383f, 85.81837f, 214.44283f, 83.55008f, 213.20813f)
    p.curveTo(82.274185f, 212.51363f, 78.32251f, 211.89423f, 74.768616f, 211.83173f)
    p.curveTo(66.642494f, 211.68892f, 62.680298f, 209.38292f, 62.680298f, 204.79663f)
    p.curveTo(62.680298f, 203.0366f, 62.105225f, 200.66708f, 61.40235f, 199.53096f)
    p.curveTo(60.366528f, 197.85664f, 60.44621f, 197.09917f, 61.822918f, 195.53287f)
    p.curveTo(62.7571f, 194.47003f, 63.689926f, 192.7139f, 63.895863f, 191.63033f)
    p.curveTo(64.39888f, 188.98361f, 74.61604f, 184.62627f, 80.70026f, 184.4637f)
    p.curveTo(85.39471f, 184.33827f, 85.41988f, 184.31837f, 82.29025f, 183.20703f)
    p.curveTo(80.54126f, 182.58595f, 78.63326f, 181.74294f, 78.05026f, 181.33368f)
    p.curveTo(76.84772f, 180.48949f, 69.568886f, 179.60466f, 68.65692f, 180.52525f)
    p.curveTo(68.32789f, 180.85739f, 67.7059f, 181.27414f, 66.619965f, 180.68747f)
    p.curveTo(64.0333f, 179.29004f, 52.713554f, 184.67496f, 50.295845f, 188.39977f)
    p.curveTo(49.251965f, 190.00801f, 47.96923f, 190.79369f, 47.00024f, 190.41832f)
    p.curveTo(46.127666f, 190.0803f, 44.546494f, 190.59604f, 43.486523f, 191.56438f)
    p.curveTo(40.95605f, 193.8761f, 38.049812f, 192.729f, 38.491005f, 189.59262f)
    p.curveTo(38.75206f, 187.73683f, 39.808556f, 186.97533f, 43.07034f, 186.2919f)
    p.curveTo(48.410545f, 185.17302f, 52.311977f, 183.29185f, 52.878662f, 181.56262f)
    p.curveTo(53.13151f, 180.79106f, 52.420235f, 180.22508f, 51.197723f, 180.22508f)
    p.curveTo(49.99161f, 180.22508f, 47.631516f, 178.38087f, 45.72033f, 175.94498f)
    p.curveTo(43.178337f, 172.70508f, 41.610996f, 171.66486f, 39.271275f, 171.66486f)
    p.curveTo(36.749187f, 171.66486f, 36.18035f, 171.21019f, 36.18035f, 169.19429f)
    p.curveTo(36.18035f, 167.83548f, 36.823486f, 165.83588f, 37.609543f, 164.7507f)
    p.curveTo(39.13905f, 162.63919f, 41.48034f, 163.29979f, 41.48034f, 165.84283f)
    p.curveTo(41.48034f, 168.47565f, 43.52249f, 167.53537f, 44.26172f, 164.56218f)
    p.curveTo(44.809414f, 162.35931f, 44.420933f, 161.32649f, 42.4923f, 159.85796f)
    p.curveTo(39.38064f, 157.4886f, 37.30043f, 158.25374f, 36.54953f, 162.04376f)
    p.curveTo(35.66268f, 166.51997f, 27.314198f, 175.23503f, 24.71183f, 174.40126f)
    p.curveTo(20.953619f, 173.19714f, 18.878756f, 176.6316f, 19.61718f, 182.83424f)
    p.curveTo(19.97181f, 185.81308f, 20.266106f, 189.30022f, 20.271173f, 190.58345f)
    p.curveTo(20.277473f, 192.17142f, 21.029604f, 193.0258f, 22.626175f, 193.25851f)
    p.curveTo(24.538574f, 193.53728f, 25.195717f, 194.68773f, 26.183073f, 199.48561f)
    p.curveTo(26.849182f, 202.72246f, 27.896843f, 206.57452f, 28.511202f, 208.04582f)
    p.curveTo(29.125563f, 209.51712f, 30.414537f, 213.43562f, 31.37559f, 216.75362f)
    p.curveTo(33.664616f, 224.65662f, 34.730244f, 225.87692f, 40.42034f, 227.11192f)
    p.curveTo(47.386765f, 228.62392f, 47.759735f, 228.59093f, 51.9552f, 226.09262f)
    p.lineTo(51.955208f, 226.09262f)
    p.moveTo(64.93928f, 216.24013f)
    p.curveTo(63.5389f, 214.53683f, 64.40436f, 213.39603f, 67.096954f, 213.39603f)
    p.curveTo(69.247665f, 213.39603f, 69.32328f, 213.54652f, 68.39687f, 215.98352f)
    p.curveTo(67.609795f, 218.05402f, 66.4984f, 218.13652f, 64.93928f, 216.24013f)
    p.lineTo(64.93928f, 216.24013f)
    p.moveTo(36.887024f, 200.91231f)
    p.curveTo(35.751595f, 199.76614f, 36.073162f, 196.4687f, 37.40116f, 195.64018f)
    p.curveTo(39.257236f, 194.48221f, 41.736572f, 198.41968f, 40.272594f, 200.20035f)
    p.curveTo(38.97654f, 201.77676f, 37.955982f, 201.9914f, 36.887024f, 200.91231f)
    p.lineTo(36.887024f, 200.91231f)
    p.moveTo(151.28383f, 210.33182f)
    p.curveTo(151.06686f, 208.05792f, 150.36076f, 205.20052f, 149.71472f, 203.98192f)
    p.curveTo(148.09447f, 200.92583f, 148.24435f, 198.24796f, 150.19281f, 195.43982f)
    p.curveTo(151.50848f, 193.54366f, 152.25432f, 193.27876f, 153.85005f, 194.14085f)
    p.curveTo(154.95253f, 194.73647f, 159.35982f, 195.52289f, 163.64403f, 195.88846f)
    p.curveTo(169.84068f, 196.41724f, 172.14491f, 196.18176f, 174.91267f, 194.73695f)
    p.curveTo(177.48601f, 193.39365f, 178.2002f, 192.45206f, 177.6557f, 191.12056f)
    p.curveTo(175.55544f, 185.98462f, 175.70537f, 185.57523f, 179.68642f, 185.57523f)
    p.curveTo(183.93356f, 185.57523f, 183.90619f, 185.60773f, 182.57263f, 182.14798f)
    p.curveTo(181.33568f, 178.93886f, 178.44098f, 168.73561f, 177.6882f, 164.93135f)
    p.curveTo(176.93126f, 161.10602f, 174.4874f, 160.16939f, 171.76129f, 162.65984f)
    p.curveTo(170.00076f, 164.26817f, 169.25623f, 164.386f, 167.56078f, 163.32463f)
    p.curveTo(166.4274f, 162.61511f, 164.54608f, 161.43724f, 163.38008f, 160.70715f)
    p.curveTo(161.6927f, 159.65062f, 160.8304f, 159.65062f, 159.15446f, 160.70715f)
    p.curveTo(157.99637f, 161.43724f, 155.88095f, 162.03458f, 154.45349f, 162.03458f)
    p.curveTo(149.66483f, 162.03458f, 146.53117f, 164.04225f, 144.08237f, 168.67915f)
    p.curveTo(142.74893f, 171.20406f, 141.41768f, 174.47368f, 141.12404f, 175.94496f)
    p.curveTo(140.75322f, 177.80295f, 139.21411f, 179.26526f, 136.08514f, 180.7324f)
    p.curveTo(133.6074f, 181.89421f, 131.58015f, 183.18591f, 131.58015f, 183.60287f)
    p.curveTo(131.58015f, 184.81847f, 135.59053f, 185.76744f, 140.93568f, 185.8167f)
    p.curveTo(143.66063f, 185.8418f, 146.27103f, 186.08139f, 146.73659f, 186.34908f)
    p.curveTo(148.22972f, 187.20761f, 145.18446f, 189.85535f, 142.7039f, 189.85535f)
    p.curveTo(140.94037f, 189.85535f, 140.15002f, 190.63266f, 139.712f, 192.79793f)
    p.curveTo(139.23656f, 195.14824f, 139.7474f, 196.27893f, 142.24997f, 198.41557f)
    p.curveTo(144.89417f, 200.67313f, 145.35432f, 201.79886f, 145.19827f, 205.62811f)
    p.curveTo(145.07243f, 208.71622f, 145.62914f, 210.85251f, 146.94102f, 212.31581f)
    p.curveTo(150.07669f, 215.8135f, 151.73462f, 215.05602f, 151.28384f, 210.33182f)
    p.lineTo(151.28383f, 210.33182f)
    p.moveTo(94.480225f, 183.43517f)
    p.curveTo(94.480225f, 182.84665f, 93.764725f, 182.36514f, 92.89023f, 182.36514f)
    p.curveTo(92.01573f, 182.36514f, 91.30023f, 182.84666f, 91.30023f, 183.43517f)
    p.curveTo(91.30023f, 184.02368f, 92.01573f, 184.50519f, 92.89023f, 184.50519f)
    p.curveTo(93.764725f, 184.50519f, 94.480225f, 184.02368f, 94.480225f, 183.43517f)
    p.lineTo(94.480225f, 183.43517f)
    p.moveTo(62.212765f, 167.28271f)
    p.curveTo(62.607433f, 166.63808f, 62.323338f, 164.96571f, 61.58144f, 163.56633f)
    p.curveTo(60.392464f, 161.32368f, 60.56619f, 160.54288f, 63.04672f, 156.98068f)
    p.curveTo(64.59452f, 154.75795f, 67.76876f, 151.34723f, 70.100586f, 149.40134f)
    p.curveTo(73.75631f, 146.35063f, 74.34027f, 145.27368f, 74.34027f, 141.58244f)
    p.curveTo(74.34027f, 135.7055f, 72.20152f, 127.621635f, 70.77378f, 128.10205f)
    p.curveTo(70.12849f, 128.31918f, 69.2736f, 130.42998f, 68.87403f, 132.7927f)
    p.curveTo(67.51766f, 140.81322f, 60.432682f, 153.47435f, 57.300888f, 153.47435f)
    p.curveTo(55.543034f, 153.47435f, 55.26031f, 152.68732f, 55.26031f, 147.79372f)
    p.curveTo(55.26031f, 144.66936f, 54.658966f, 141.2829f, 53.92399f, 140.26825f)
    p.curveTo(52.713417f, 138.59702f, 52.21467f, 138.87387f, 48.624f, 143.21011f)
    p.curveTo(46.443985f, 145.84279f, 44.66034f, 148.49005f, 44.66034f, 149.09288f)
    p.curveTo(44.66034f, 150.58546f, 48.750126f, 152.69148f, 50.404278f, 152.0507f)
    p.curveTo(53.349316f, 150.9099f, 57.380306f, 156.69284f, 57.380306f, 162.05867f)
    p.curveTo(57.380306f, 167.06686f, 60.3677f, 170.29634f, 62.21276f, 167.28271f)
    p.lineTo(62.212765f, 167.28271f)
    p.moveTo(36.18036f, 147.58919f)
    p.curveTo(36.18036f, 146.70642f, 35.70336f, 145.98415f, 35.12036f, 145.98415f)
    p.curveTo(34.537365f, 145.98415f, 34.060364f, 146.70642f, 34.060364f, 147.58919f)
    p.curveTo(34.060364f, 148.47197f, 34.53736f, 149.19424f, 35.12036f, 149.19424f)
    p.curveTo(35.70336f, 149.19424f, 36.18036f, 148.47197f, 36.18036f, 147.58919f)
    p.lineTo(36.18036f, 147.58919f)
    p.moveTo(72.89694f, 119.768425f)
    p.curveTo(73.23253f, 118.88566f, 73.18348f, 117.32073f, 72.78797f, 116.29083f)
    p.curveTo(72.1178f, 114.54573f, 71.9658f, 114.55964f, 70.554565f, 116.495346f)
    p.curveTo(69.7217f, 117.63773f, 69.040276f, 119.20266f, 69.040276f, 119.972946f)
    p.curveTo(69.040276f, 121.905846f, 72.14706f, 121.7411f, 72.89694f, 119.768425f)
    p.lineTo(72.89694f, 119.768425f)
    p.moveTo(149.04288f, 118.21652f)
    p.curveTo(150.87823f, 114.63375f, 151.18611f, 108.987595f, 149.6001f, 107.9981f)
    p.curveTo(149.0171f, 107.63438f, 148.5401f, 105.4925f, 148.5401f, 103.23837f)
    p.curveTo(148.5401f, 100.780525f, 147.723f, 98.12875f, 146.49886f, 96.61383f)
    p.curveTo(144.51874f, 94.16336f, 144.4368f, 94.15181f, 143.76262f, 96.22778f)
    p.curveTo(141.78067f, 102.330765f, 139.66371f, 100.01361f, 136.2151f, 100.348076f)
    p.curveTo(131.77325f, 100.778854f, 130.79346f, 105.9376f, 134.08089f, 108.79089f)
    p.curveTo(134.74629f, 109.36843f, 135.08331f, 110.52503f, 136.13794f, 111.675064f)
    p.curveTo(138.44246f, 114.18803f, 137.2747f, 114.274185f, 142.49791f, 118.15172f)
    p.curveTo(144.88483f, 119.92369f, 146.97003f, 121.37348f, 147.1317f, 121.37348f)
    p.curveTo(147.29338f, 121.37348f, 148.15341f, 119.95285f, 149.04286f, 118.21653f)
    p.lineTo(149.04288f, 118.21652f)
    p.moveTo(73.28028f, 108.596275f)
    p.curveTo(73.28028f, 103.543076f, 71.62121f, 102.061104f, 69.99574f, 105.66237f)
    p.curveTo(69.13201f, 107.57599f, 69.14068f, 108.86316f, 70.028496f, 110.53784f)
    p.curveTo(71.89725f, 114.06268f, 73.28025f, 113.23691f, 73.28025f, 108.59628f)
    p.lineTo(73.28028f, 108.596275f)
    p.moveTo(54.00003f, 90.89753f)
    p.curveTo(54.34734f, 85.45898f, 52.784187f, 83.07073f, 50.260876f, 85.18472f)
    p.curveTo(47.540882f, 87.46347f, 49.450104f, 97.46195f, 52.417088f, 96.476685f)
    p.curveTo(53.106365f, 96.24779f, 53.81869f, 93.73717f, 54.00003f, 90.89754f)
    p.lineTo(54.00003f, 90.89753f)
    p.moveTo(72.95534f, 84.92498f)
    p.curveTo(74.6722f, 81.98639f, 75.25398f, 81.71561f, 78.58025f, 82.30696f)
    p.curveTo(80.62075f, 82.66972f, 83.12499f, 83.21407f, 84.14524f, 83.516594f)
    p.curveTo(88.17233f, 84.71078f, 85.703255f, 81.529816f, 80.96525f, 79.41975f)
    p.curveTo(78.19601f, 78.18647f, 74.15099f, 76.04674f, 71.97633f, 74.66479f)
    p.curveTo(69.801674f, 73.28283f, 67.77443f, 72.152145f, 67.471344f, 72.152145f)
    p.curveTo(66.704765f, 72.152145f, 66.78069f, 80.81033f, 67.58278f, 84.858734f)
    p.curveTo(68.42313f, 89.10023f, 70.50099f, 89.12585f, 72.95534f, 84.924934f)
    p.lineTo(72.95534f, 84.92498f)
    p.moveTo(174.55821f, 58.825397f)
    p.curveTo(176.54456f, 56.82028f, 177.16003f, 55.06751f, 177.16003f, 51.41594f)
    p.curveTo(177.16003f, 47.02128f, 176.64998f, 46.105087f, 170.87807f, 40.132f)
    p.curveTo(167.42299f, 36.5565f, 163.86209f, 33.63108f, 162.96495f, 33.63108f)
    p.curveTo(162.06784f, 33.63108f, 159.57188f, 32.06945f, 157.41843f, 30.160791f)
    p.curveTo(155.26495f, 28.252111f, 151.39436f, 26.150002f, 148.8171f, 25.48941f)
    p.curveTo(144.51503f, 24.38674f, 143.65059f, 24.53645f, 138.2649f, 27.31685f)
    p.curveTo(135.03845f, 28.98253f, 131.84859f, 31.1047f, 131.17633f, 32.03278f)
    p.curveTo(130.50407f, 32.96086f, 128.76965f, 34.31311f, 127.32209f, 35.03778f)
    p.curveTo(125.362f, 36.01903f, 124.6074f, 37.35257f, 124.36597f, 40.261932f)
    p.curveTo(124.187675f, 42.410534f, 123.35293f, 44.74562f, 122.51098f, 45.45098f)
    p.curveTo(120.144066f, 47.43394f, 120.66726f, 49.1866f, 124.509155f, 52.1447f)
    p.curveTo(127.62762f, 54.54577f, 128.76826f, 54.79865f, 134.31412f, 54.318428f)
    p.curveTo(139.01811f, 53.91111f, 141.65213f, 54.26383f, 144.8301f, 55.72688f)
    p.curveTo(147.31937f, 56.87281f, 152.13387f, 57.797268f, 156.49007f, 57.96574f)
    p.curveTo(160.57106f, 58.12358f, 164.98329f, 58.30119f, 166.29504f, 58.36043f)
    p.curveTo(167.6068f, 58.41973f, 168.68004f, 59.13948f, 168.68004f, 59.960003f)
    p.curveTo(168.68004f, 62.295223f, 171.69798f, 61.71271f, 174.5582f, 58.825413f)
    p.lineTo(174.55821f, 58.825397f)
    p.moveTo(25.32069f, 47.27396f)
    p.curveTo(24.81541f, 45.72516f, 20.280396f, 44.77567f, 20.280396f, 46.21867f)
    p.curveTo(20.280396f, 47.74673f, 21.525408f, 48.61149f, 23.725388f, 48.61149f)
    p.curveTo(24.876778f, 48.61149f, 25.567986f, 48.031967f, 25.32069f, 47.27396f)
    p.lineTo(25.32069f, 47.27396f)
    p.moveTo(24.520386f, 22.99395f)
    p.curveTo(24.520386f, 20.25576f, 22.694185f, 19.21253f, 20.75089f, 20.84059f)
    p.curveTo(19.56895f, 21.83079f, 19.483795f, 22.49687f, 20.397118f, 23.60778f)
    p.curveTo(22.155209f, 25.7462f, 24.520386f, 25.394081f, 24.520386f, 22.99395f)
    p.lineTo(24.520386f, 22.99395f)
    p.moveTo(50.219692f, 34.96673f)
    p.curveTo(49.49404f, 34.722557f, 48.90033f, 33.93509f, 48.90033f, 33.216797f)
    p.curveTo(50.029682f, 26.092556f, 63.34581f, 21.895037f, 60.261326f, 31.804157f)
    p.curveTo(59.643826f, 33.428566f, 52.414745f, 35.705338f, 50.219696f, 34.96673f)
    p.lineTo(50.219692f, 34.96673f)
  }

  private def mkPath5(p: Path2D): Unit = {
    p.moveTo(83.625f, 18.843748f)
    p.curveTo(84.05282f, 21.564938f, 86.48854f, 22.910109f, 91.59375f, 23.593748f)
    p.lineTo(96.875f, 24.312498f)
    p.lineTo(94.34375f, 26.343748f)
    p.curveTo(92.95519f, 27.461267f, 90.73242f, 28.841358f, 89.375f, 29.406248f)
    p.curveTo(87.31942f, 30.261688f, 86.99612f, 30.959368f, 87.5625f, 33.5625f)
    p.curveTo(88.38121f, 37.32534f, 84.88743f, 43.26704f, 79.09375f, 47.90625f)
    p.curveTo(76.33334f, 50.11661f, 75.46848f, 51.47704f, 75.9375f, 52.96875f)
    p.curveTo(76.35033f, 54.28178f, 75.57804f, 56.33063f, 73.75f, 58.75f)
    p.curveTo(70.73747f, 62.73701f, 67.335464f, 63.92186f, 68.25f, 60.65625f)
    p.curveTo(68.53843f, 59.62635f, 68.97069f, 58.09783f, 69.1875f, 57.25f)
    p.curveTo(69.40432f, 56.40217f, 68.76778f, 55.49993f, 67.78125f, 55.28125f)
    p.curveTo(65.30624f, 54.73263f, 62.349308f, 60.71012f, 63.1875f, 64.5625f)
    p.curveTo(63.80768f, 67.41289f, 63.6193f, 67.55294f, 57.6875f, 68.875f)
    p.curveTo(48.85981f, 70.84249f, 48.757668f, 70.89277f, 48.1875f, 73.09375f)
    p.curveTo(47.602898f, 75.35042f, 44.829422f, 77.01571f, 39.375f, 78.34375f)
    p.curveTo(36.770355f, 78.97793f, 35.54322f, 79.90869f, 35.3125f, 81.5f)
    p.curveTo(34.73751f, 85.46571f, 32.472637f, 86.38491f, 30.84375f, 83.3125f)
    p.curveTo(30.146322f, 81.99701f, 29.60682f, 81.36231f, 28.71875f, 81.125f)
    p.lineTo(28.71875f, 171.3125f)
    p.curveTo(30.617943f, 169.69345f, 32.381866f, 166.84447f, 36.25f, 160.15625f)
    p.curveTo(37.3562f, 158.24358f, 39.096184f, 156.66481f, 40.125f, 156.65625f)
    p.curveTo(43.971287f, 156.62254f, 44.714725f, 155.2254f, 43.71875f, 149.84375f)
    p.curveTo(42.815403f, 144.9626f, 42.887135f, 144.70735f, 45.5625f, 143.5625f)
    p.curveTo(47.098534f, 142.9052f, 49.38888f, 141.47058f, 50.625f, 140.375f)
    p.curveTo(52.84812f, 138.40463f, 52.89198f, 138.42949f, 55.125f, 142.25f)
    p.curveTo(56.366627f, 144.37431f, 57.375f, 147.0884f, 57.375f, 148.28125f)
    p.curveTo(57.375f, 150.26268f, 57.72653f, 150.16692f, 61.53125f, 147.125f)
    p.curveTo(65.566154f, 143.89905f, 68.38011f, 138.07346f, 69.25f, 131.09375f)
    p.curveTo(70.1943f, 123.51696f, 74.34375f, 132.04407f, 74.34375f, 141.5625f)
    p.curveTo(74.34375f, 145.20357f, 73.73775f, 146.34715f, 70.125f, 149.46875f)
    p.curveTo(65.2981f, 153.6395f, 62.283386f, 160.52242f, 63.96875f, 163.5625f)
    p.curveTo(66.441124f, 168.0222f, 57.49108f, 174.06721f, 54.25f, 170.125f)
    p.curveTo(52.833042f, 168.4015f, 50.01623f, 168.03152f, 46.09375f, 169.09375f)
    p.lineTo(43.8125f, 169.71875f)
    p.lineTo(46.34375f, 173.53125f)
    p.curveTo(47.747135f, 175.61882f, 48.90625f, 177.67639f, 48.90625f, 178.125f)
    p.curveTo(48.90625f, 178.57361f, 51.88751f, 179.30043f, 55.53125f, 179.75f)
    p.curveTo(59.17499f, 180.19958f, 63.115253f, 180.73524f, 64.28125f, 180.9375f)
    p.curveTo(67.11446f, 181.42902f, 67.80442f, 181.42766f, 72.75f, 180.9687f)
    p.curveTo(75.08199f, 180.75232f, 77.4795f, 180.9344f, 78.0625f, 181.3437f)
    p.curveTo(78.6455f, 181.75296f, 80.53225f, 182.59763f, 82.28125f, 183.2187f)
    p.curveTo(85.43742f, 184.33952f, 85.44549f, 184.32231f, 80.90625f, 184.4062f)
    p.curveTo(78.39083f, 184.4527f, 73.97567f, 185.51201f, 71.125f, 186.74995f)
    p.curveTo(66.35743f, 188.82031f, 66.01565f, 189.2398f, 66.5625f, 191.99995f)
    p.curveTo(67.02982f, 194.35866f, 66.65716f, 195.28462f, 64.8125f, 196.2812f)
    p.curveTo(63.096325f, 197.20836f, 62.7666f, 197.85219f, 63.625f, 198.7187f)
    p.curveTo(64.27059f, 199.3704f, 64.8125f, 201.24068f, 64.8125f, 202.87495f)
    p.curveTo(64.8125f, 207.28673f, 68.83396f, 209.55202f, 75.28125f, 208.78122f)
    p.curveTo(79.21107f, 208.31133f, 81.14086f, 208.66742f, 83.71875f, 210.24992f)
    p.curveTo(85.55904f, 211.37973f, 87.0625f, 212.81502f, 87.0625f, 213.46872f)
    p.curveTo(87.0625f, 213.57332f, 87.0407f, 213.71922f, 87.0313f, 213.84372f)
    p.lineTo(145.62506f, 213.84372f)
    p.curveTo(143.79137f, 211.90051f, 143.25006f, 209.76093f, 143.25006f, 206.18742f)
    p.curveTo(143.25006f, 203.28197f, 142.47594f, 200.43497f, 141.18756f, 198.62495f)
    p.curveTo(138.94339f, 195.47214f, 140.66519f, 192.60231f, 141.65631f, 189.8437f)
    p.curveTo(142.15999f, 188.44182f, 144.31256f, 187.69296f, 144.31256f, 186.24995f)
    p.curveTo(144.31256f, 186.12889f, 142.3623f, 185.93883f, 140.00006f, 185.8437f)
    p.curveTo(135.10721f, 185.64674f, 131.59381f, 184.70589f, 131.59381f, 183.5937f)
    p.curveTo(131.59381f, 183.17674f, 133.61607f, 181.88051f, 136.09381f, 180.7187f)
    p.curveTo(139.22353f, 179.25119f, 141.22943f, 177.14894f, 141.47327f, 175.41066f)
    p.curveTo(141.66632f, 174.0345f, 142.59795f, 171.38736f, 144.18756f, 168.6562f)
    p.curveTo(146.39966f, 164.8555f, 147.9261f, 163.47124f, 150.71881f, 162.7812f)
    p.curveTo(152.72565f, 162.28535f, 156.51283f, 162.271f, 159.54916f, 161.31691f)
    p.curveTo(164.71329f, 159.69421f, 165.54153f, 158.51784f, 167.43756f, 160.2499f)
    p.curveTo(168.74515f, 161.44443f, 169.49236f, 161.80673f, 170.84381f, 161.40614f)
    p.lineTo(170.84381f, 62.968643f)
    p.curveTo(169.09592f, 63.864563f, 167.75838f, 63.578693f, 166.37506f, 62.187393f)
    p.curveTo(162.46808f, 58.257862f, 159.91037f, 56.362034f, 155.6206f, 57.093643f)
    p.curveTo(152.2921f, 57.661312f, 150.1571f, 57.263752f, 146.3081f, 55.437393f)
    p.curveTo(142.2751f, 53.523724f, 139.3988f, 53.815575f, 134.31256f, 54.281143f)
    p.curveTo(128.72969f, 54.792164f, 127.63326f, 54.56856f, 124.50006f, 52.156143f)
    p.curveTo(120.65816f, 49.198044f, 120.13315f, 47.420353f, 122.50006f, 45.437393f)
    p.curveTo(123.34202f, 44.732033f, 124.19677f, 42.398502f, 124.37506f, 40.249893f)
    p.curveTo(124.610634f, 37.411133f, 125.38269f, 36.028145f, 127.18756f, 35.124893f)
    p.curveTo(128.55363f, 34.441235f, 130.48286f, 32.500862f, 131.50006f, 30.812393f)
    p.curveTo(134.58757f, 25.687363f, 140.57541f, 21.677364f, 144.00006f, 22.468643f)
    p.curveTo(155.80968f, 25.197323f, 165.87965f, 30.834763f, 169.96881f, 36.999893f)
    p.curveTo(170.24634f, 37.418304f, 170.53516f, 37.819183f, 170.84381f, 38.218643f)
    p.lineTo(170.84381f, 26.031143f)
    p.curveTo(167.02246f, 25.796793f, 164.43756f, 24.645884f, 164.43756f, 22.874893f)
    p.curveTo(164.43756f, 20.671824f, 165.05777f, 20.458033f, 170.43756f, 20.749893f)
    p.curveTo(170.57632f, 20.757893f, 170.70651f, 20.746893f, 170.84381f, 20.749893f)
    p.lineTo(170.84381f, 18.843643f)
    p.lineTo(83.625f, 18.843748f)
    p.moveTo(28.71875f, 33.84375f)
    p.lineTo(28.71875f, 43.09375f)
    p.curveTo(30.010904f, 42.94845f, 30.958977f, 42.47754f, 31.53125f, 41.6875f)
    p.curveTo(32.9038f, 39.79266f, 32.276726f, 35.69154f, 30.4375f, 34.4375f)
    p.curveTo(30.02752f, 34.15796f, 29.421963f, 33.97177f, 28.71875f, 33.84375f)
    p.lineTo(28.71875f, 33.84375f)
    p.moveTo(66.53125f, 70.0f)
    p.curveTo(66.89753f, 70.0f, 69.63904f, 71.39048f, 72.625f, 73.09375f)
    p.curveTo(75.61096f, 74.79703f, 79.7095f, 76.53146f, 81.75f, 76.9375f)
    p.curveTo(86.34785f, 77.85245f, 91.3125f, 79.90839f, 91.3125f, 80.90625f)
    p.curveTo(91.3125f, 83.22704f, 86.54722f, 84.73442f, 80.875f, 84.21875f)
    p.curveTo(75.6972f, 83.74803f, 74.5825f, 83.99091f, 72.84375f, 85.9375f)
    p.curveTo(69.65587f, 89.50644f, 68.35909f, 88.64228f, 67.0625f, 82.125f)
    p.curveTo(65.73301f, 75.4423f, 65.499535f, 70.0f, 66.53125f, 70.0f)
    p.lineTo(66.53125f, 70.0f)
    p.moveTo(144.5625f, 94.84375f)
    p.curveTo(144.99672f, 94.74435f, 145.53769f, 95.43411f, 146.5f, 96.625f)
    p.curveTo(147.72415f, 98.13993f, 147.31589f, 102.04512f, 147.64737f, 104.76523f)
    p.curveTo(148.19272f, 109.24029f, 151.39423f, 113.360535f, 149.03125f, 118.21875f)
    p.curveTo(148.14178f, 119.95508f, 145.91614f, 119.23214f, 145.69196f, 119.23214f)
    p.curveTo(138.27846f, 116.47061f, 137.59944f, 111.33577f, 134.0625f, 107.28125f)
    p.curveTo(132.60023f, 105.65018f, 132.10745f, 104.60519f, 133.5625f, 102.5f)
    p.curveTo(134.04256f, 101.80543f, 135.28966f, 99.77636f, 138.5625f, 100.3125f)
    p.curveTo(140.99796f, 100.71146f, 142.41261f, 100.49209f, 142.65625f, 99.65625f)
    p.curveTo(143.60704f, 96.39445f, 144.00421f, 94.97161f, 144.5625f, 94.84375f)
    p.lineTo(144.5625f, 94.84375f)
    p.moveTo(31.96875f, 138.8125f)
    p.curveTo(32.671867f, 138.7612f, 33.428917f, 139.4945f, 34.03125f, 141.09375f)
    p.curveTo(34.603405f, 142.61287f, 35.42332f, 143.86644f, 35.875f, 143.875f)
    p.curveTo(38.40897f, 143.9256f, 39.54772f, 145.788f, 38.375f, 148.0f)
    p.curveTo(35.742584f, 152.96526f, 29.39295f, 148.93631f, 30.0f, 142.6875f)
    p.curveTo(30.239143f, 140.22581f, 31.06474f, 138.87842f, 31.96875f, 138.8125f)
    p.lineTo(31.96875f, 138.8125f)
    p.moveTo(51.0f, 155.78125f)
    p.curveTo(50.611427f, 155.79485f, 50.311764f, 156.10309f, 49.90625f, 156.75f)
    p.curveTo(49.376614f, 157.59494f, 48.915154f, 159.41615f, 48.90625f, 160.78125f)
    p.curveTo(48.8934f, 162.74672f, 49.39259f, 163.17702f, 51.28125f, 162.90625f)
    p.curveTo(54.214996f, 162.48566f, 55.019314f, 158.68832f, 52.59375f, 156.65625f)
    p.curveTo(51.868637f, 156.04877f, 51.388573f, 155.7677f, 51.0f, 155.78125f)
    p.lineTo(51.0f, 155.78125f)
    p.moveTo(28.71875f, 213.18752f)
    p.lineTo(28.71875f, 213.84372f)
    p.lineTo(28.96875f, 213.84372f)
    p.curveTo(28.88126f, 213.62712f, 28.806944f, 213.40092f, 28.71875f, 213.18752f)
    p.lineTo(28.71875f, 213.18752f)
  }

  private def mkPath6(p: Path2D): Unit = {
    p.moveTo(85.48676f, 242.50102f)
    p.curveTo(83.22337f, 241.95403f, 81.5985f, 240.41022f, 79.77593f, 237.07503f)
    p.lineTo(77.22858f, 232.41342f)
    p.lineTo(71.279434f, 233.04453f)
    p.curveTo(67.33257f, 233.46332f, 64.512764f, 233.21353f, 62.901264f, 232.30212f)
    p.curveTo(60.54735f, 230.97102f, 60.532974f, 230.87312f, 62.43633f, 229.13432f)
    p.curveTo(64.02239f, 227.68542f, 65.100624f, 227.54262f, 68.03835f, 228.39322f)
    p.curveTo(73.4308f, 229.95442f, 80.312775f, 229.68472f, 82.139534f, 227.84062f)
    p.curveTo(83.59967f, 226.36671f, 87.06024f, 216.26942f, 87.06024f, 213.48312f)
    p.curveTo(87.06024f, 212.82933f, 85.55455f, 211.37022f, 83.71426f, 210.24042f)
    p.curveTo(81.13636f, 208.65791f, 79.19737f, 208.32632f, 75.26755f, 208.79622f)
    p.curveTo(68.82026f, 209.56702f, 64.80029f, 207.29681f, 64.80029f, 202.88504f)
    p.curveTo(64.80029f, 201.25076f, 63.76309f, 198.87167f, 63.150154f, 198.25294f)
    p.curveTo(62.37092f, 197.46634f, 63.419437f, 197.1028f, 65.39082f, 195.79887f)
    p.curveTo(67.730095f, 194.25162f, 68.945755f, 194.12253f, 72.5297f, 195.04085f)
    p.curveTo(76.18091f, 195.9764f, 77.059555f, 195.86781f, 78.20884f, 194.33904f)
    p.curveTo(80.18278f, 191.71329f, 79.39975f, 190.4355f, 75.58364f, 190.05507f)
    p.curveTo(72.393936f, 189.73708f, 71.222336f, 188.4642f, 73.0626f, 187.31609f)
    p.curveTo(73.52587f, 187.02707f, 86.62245f, 186.44792f, 102.16609f, 186.02913f)
    p.curveTo(126.94377f, 185.36154f, 130.74132f, 185.47539f, 132.97498f, 186.9528f)
    p.curveTo(137.58026f, 189.99884f, 139.03018f, 192.03702f, 138.39868f, 194.57692f)
    p.curveTo(137.94707f, 196.39336f, 138.47998f, 197.45648f, 140.51773f, 198.8043f)
    p.curveTo(142.80907f, 200.31985f, 143.24013f, 201.41049f, 143.24013f, 205.69232f)
    p.curveTo(143.24013f, 211.69682f, 144.78648f, 214.23901f, 150.20245f, 217.13852f)
    p.curveTo(153.61475f, 218.96542f, 155.8789f, 217.79321f, 156.32968f, 216.42352f)
    p.curveTo(157.08765f, 214.12062f, 160.46915f, 211.35883f, 162.91019f, 209.20372f)
    p.curveTo(164.99948f, 207.35922f, 167.60928f, 206.17732f, 169.74005f, 204.38081f)
    p.curveTo(173.17908f, 201.48134f, 175.32935f, 195.62859f, 179.27534f, 194.83191f)
    p.curveTo(181.28044f, 194.4271f, 182.46002f, 193.53091f, 182.46002f, 192.41235f)
    p.curveTo(182.46002f, 191.43523f, 183.67937f, 189.49501f, 185.1697f, 188.10077f)
    p.curveTo(186.79247f, 186.5826f, 187.55957f, 185.04346f, 187.08209f, 184.2636f)
    p.curveTo(186.6436f, 183.5474f, 186.38814f, 181.59303f, 186.51437f, 179.92056f)
    p.curveTo(186.66849f, 177.8788f, 185.6919f, 175.59138f, 183.54196f, 172.95847f)
    p.curveTo(181.78091f, 170.80177f, 180.34003f, 168.46367f, 180.34003f, 167.76268f)
    p.curveTo(180.34003f, 165.53644f, 176.6855f, 159.90834f, 175.23535f, 159.9013f)
    p.curveTo(174.46828f, 159.8983f, 172.82939f, 160.44089f, 171.5934f, 161.10864f)
    p.curveTo(169.69157f, 162.1361f, 169.00233f, 161.91927f, 167.10976f, 159.6982f)
    p.curveTo(164.93164f, 157.14203f, 164.75163f, 157.11464f, 160.19908f, 158.64651f)
    p.curveTo(156.54608f, 159.8757f, 154.59071f, 159.9677f, 151.24985f, 159.06752f)
    p.curveTo(146.32443f, 157.74042f, 144.30011f, 158.77097f, 144.30011f, 162.60551f)
    p.curveTo(144.30011f, 163.95702f, 142.99384f, 166.17596f, 141.38512f, 167.55714f)
    p.curveTo(139.24437f, 169.39508f, 138.41774f, 171.1548f, 138.2729f, 174.18236f)
    p.curveTo(138.16441f, 176.44975f, 137.76817f, 178.61656f, 137.39233f, 178.99748f)
    p.curveTo(137.01651f, 179.3784f, 125.418785f, 179.93083f, 111.61964f, 180.22508f)
    p.curveTo(89.07817f, 180.70576f, 86.19461f, 180.56993f, 83.22515f, 178.88756f)
    p.curveTo(79.3246f, 176.67766f, 71.30495f, 176.4249f, 68.5934f, 178.42639f)
    p.curveTo(66.24812f, 180.15752f, 49.620377f, 180.35811f, 49.039597f, 178.59926f)
    p.curveTo(48.82953f, 177.96309f, 47.09317f, 175.57794f, 45.8256f, 173.49323f)
    p.lineTo(43.261406f, 169.27602f)
    p.lineTo(46.440876f, 168.47821f)
    p.curveTo(50.38245f, 167.48917f, 52.56587f, 168.19801f, 54.24481f, 169.66748f)
    p.curveTo(57.81759f, 172.7945f, 65.92255f, 167.70567f, 63.477524f, 163.09386f)
    p.curveTo(61.87042f, 160.06253f, 65.89003f, 152.9971f, 69.98557f, 150.85916f)
    p.curveTo(71.76311f, 149.93126f, 73.752f, 148.1638f, 74.40534f, 146.93147f)
    p.curveTo(75.889824f, 144.13144f, 74.75697f, 131.33716f, 72.66399f, 127.264725f)
    p.curveTo(71.38184f, 124.77003f, 71.39494f, 124.072136f, 72.760864f, 122.10361f)
    p.curveTo(74.71886f, 119.281715f, 74.865486f, 108.05797f, 73.02224f, 102.0961f)
    p.curveTo(72.29726f, 99.7513f, 71.39739f, 97.83284f, 71.022514f, 97.83284f)
    p.curveTo(69.786156f, 97.83284f, 68.98262f, 104.5975f, 68.575066f, 118.437f)
    p.curveTo(68.06973f, 135.59639f, 66.59127f, 141.6795f, 61.73452f, 146.58221f)
    p.lineTo(57.668728f, 151.48668f)
    p.lineTo(56.587383f, 145.21248f)
    p.curveTo(56.09117f, 142.33334f, 54.87567f, 137.56215f, 54.541733f, 134.46158f)
    p.curveTo(54.20779f, 131.36101f, 53.51647f, 128.56334f, 53.005466f, 128.24452f)
    p.curveTo(51.662483f, 127.40666f, 49.737873f, 133.17339f, 50.430607f, 135.95958f)
    p.curveTo(51.310455f, 139.49835f, 49.581615f, 140.73451f, 46.244827f, 143.24245f)
    p.curveTo(43.74946f, 145.11795f, 42.80451f, 144.79555f, 43.67723f, 149.35524f)
    p.curveTo(44.167168f, 151.915f, 44.5888f, 154.35672f, 44.61419f, 154.7813f)
    p.curveTo(44.63958f, 155.20584f, 43.377964f, 156.31062f, 41.48322f, 156.7998f)
    p.curveTo(38.87622f, 157.4729f, 37.113388f, 158.54826f, 35.069527f, 162.33174f)
    p.curveTo(31.20296f, 169.48926f, 28.752922f, 173.23778f, 24.429207f, 173.4488f)
    p.curveTo(19.60583f, 173.68423f, 17.909718f, 177.80296f, 18.756191f, 184.24438f)
    p.curveTo(19.34345f, 188.71326f, 19.120893f, 189.87256f, 17.348608f, 191.5765f)
    p.curveTo(16.190783f, 192.68968f, 14.91376f, 194.68349f, 14.510778f, 196.00719f)
    p.curveTo(13.924889f, 197.93172f, 14.302665f, 198.61525f, 16.396284f, 199.4188f)
    p.curveTo(17.836292f, 199.97147f, 19.327465f, 200.93486f, 19.710005f, 201.55968f)
    p.curveTo(20.092543f, 202.1845f, 21.266966f, 202.69571f, 22.319832f, 202.69571f)
    p.curveTo(24.287207f, 202.69571f, 29.342182f, 213.09183f, 32.030243f, 222.66623f)
    p.curveTo(33.107597f, 226.50352f, 33.770866f, 227.21413f, 36.81352f, 227.79033f)
    p.curveTo(41.407516f, 228.66032f, 42.521492f, 230.51653f, 38.449623f, 230.51653f)
    p.curveTo(33.795647f, 230.51653f, 31.94236f, 231.53662f, 31.924154f, 234.10852f)
    p.curveTo(31.886354f, 239.44832f, 30.337248f, 239.41953f, 23.87778f, 233.95901f)
    p.curveTo(15.408066f, 226.79892f, 5.678009f, 216.30602f, 4.426241f, 212.98251f)
    p.curveTo(1.9159071f, 206.31741f, 1.3041656f, 184.69048f, 1.5860486f, 112.57363f)
    p.curveTo(1.8661032f, 40.92437f, 1.9852797f, 36.78159f, 3.8254228f, 34.729008f)
    p.curveTo(6.0879693f, 32.205257f, 8.055216f, 31.856108f, 7.1901274f, 34.13183f)
    p.curveTo(6.340003f, 36.368187f, 8.517469f, 37.37101f, 10.015945f, 35.433247f)
    p.curveTo(11.01556f, 34.1406f, 12.347147f, 33.989117f, 16.570402f, 34.687607f)
    p.curveTo(19.61033f, 35.190388f, 22.2998f, 35.152016f, 22.877388f, 34.597607f)
    p.curveTo(24.083532f, 33.439907f, 28.82623f, 33.347355f, 30.443348f, 34.449966f)
    p.curveTo(32.282574f, 35.704006f, 32.88901f, 39.795925f, 31.516459f, 41.690765f)
    p.curveTo(30.667406f, 42.862904f, 29.0627f, 43.315117f, 26.59359f, 43.078033f)
    p.curveTo(21.606674f, 43.548172f, 24.229076f, 36.686684f, 23.489676f, 36.306133f)
    p.curveTo(21.358797f, 36.863983f, 20.983093f, 40.997654f, 19.164587f, 41.427925f)
    p.curveTo(17.776669f, 41.688805f, 16.794327f, 39.812614f, 15.442386f, 39.404415f)
    p.curveTo(13.923641f, 38.945847f, 11.592814f, 37.581314f, 10.70163f, 38.983574f)
    p.curveTo(9.030739f, 41.612682f, 10.016874f, 43.667564f, 14.037395f, 45.934563f)
    p.curveTo(16.126648f, 47.112602f, 19.097834f, 48.972042f, 20.640028f, 50.066654f)
    p.curveTo(22.182222f, 51.161263f, 24.147924f, 51.784184f, 25.008253f, 51.450912f)
    p.curveTo(26.972898f, 50.689884f, 28.089209f, 52.380573f, 26.962748f, 54.411064f)
    p.curveTo(26.493946f, 55.256104f, 24.027077f, 57.470734f, 21.480816f, 59.332474f)
    p.curveTo(18.934557f, 61.194214f, 16.61318f, 63.636475f, 16.3222f, 64.759705f)
    p.curveTo(15.704625f, 67.143684f, 13.920408f, 67.51538f, 13.920408f, 65.260086f)
    p.curveTo(13.920408f, 62.749428f, 11.587332f, 62.045086f, 10.095035f, 64.10524f)
    p.curveTo(8.949019f, 65.68734f, 8.97465f, 66.52971f, 10.244215f, 69.00802f)
    p.curveTo(11.0873375f, 70.65386f, 12.711993f, 72.299965f, 13.854562f, 72.66604f)
    p.curveTo(14.997131f, 73.03212f, 16.232126f, 74.28631f, 16.598993f, 75.45314f)
    p.curveTo(17.907923f, 79.61624f, 21.52942f, 81.93826f, 25.624235f, 81.23989f)
    p.curveTo(28.909452f, 80.67961f, 29.766441f, 80.592384f, 31.021072f, 82.95886f)
    p.curveTo(32.64996f, 86.03127f, 34.38959f, 85.10899f, 34.964577f, 81.14328f)
    p.curveTo(35.195297f, 79.55198f, 36.21999f, 78.8754f, 38.82463f, 78.24121f)
    p.curveTo(44.279053f, 76.91318f, 46.95986f, 75.1333f, 47.912548f, 73.0057f)
    p.curveTo(48.9169f, 70.762695f, 50.077347f, 69.24497f, 57.20608f, 68.95439f)
    p.curveTo(60.945084f, 68.80197f, 63.226723f, 67.9956f, 63.88721f, 68.66234f)
    p.curveTo(64.451164f, 69.23163f, 65.298134f, 73.55821f, 65.76938f, 78.27696f)
    p.curveTo(66.24062f, 82.99572f, 66.95901f, 87.40015f, 67.36579f, 88.06455f)
    p.curveTo(68.61424f, 90.103714f, 71.02012f, 89.41322f, 72.932526f, 86.466896f)
    p.curveTo(74.63861f, 83.838455f, 75.48784f, 83.34385f, 81.079056f, 83.93378f)
    p.curveTo(85.508415f, 84.40111f, 87.56941f, 83.84508f, 89.08447f, 82.39799f)
    p.curveTo(91.61105f, 79.984764f, 92.37557f, 80.33005f, 81.63343f, 77.52746f)
    p.curveTo(78.89108f, 76.81199f, 73.70433f, 73.81127f, 70.21645f, 71.51395f)
    p.curveTo(62.946224f, 66.72535f, 61.535206f, 63.580875f, 64.26524f, 58.251606f)
    p.curveTo(66.396416f, 54.091366f, 68.605225f, 54.625114f, 68.23452f, 59.210754f)
    p.curveTo(67.90405f, 63.298706f, 69.55541f, 66.80199f, 71.812836f, 66.80199f)
    p.curveTo(72.733574f, 66.80199f, 74.164474f, 64.96799f, 75.080605f, 62.613647f)
    p.curveTo(75.977005f, 60.310066f, 77.57986f, 58.195797f, 78.642525f, 57.915276f)
    p.curveTo(80.111534f, 57.527485f, 80.65321f, 56.167316f, 80.90244f, 52.240585f)
    p.curveTo(81.20735f, 47.436607f, 81.47081f, 47.006676f, 84.67524f, 46.083885f)
    p.curveTo(88.20471f, 45.067486f, 89.48526f, 42.191315f, 86.408325f, 42.191315f)
    p.curveTo(84.85043f, 42.191315f, 86.5613f, 40.871143f, 87.10889f, 39.447254f)
    p.curveTo(87.89686f, 37.398304f, 88.034225f, 35.671665f, 87.5764f, 33.567486f)
    p.curveTo(87.0075f, 30.952785f, 87.304214f, 30.261116f, 89.36218f, 29.404686f)
    p.curveTo(90.719604f, 28.839796f, 92.966324f, 27.463285f, 94.35489f, 26.345766f)
    p.lineTo(96.87956f, 24.313927f)
    p.lineTo(91.58905f, 23.605476f)
    p.curveTo(84.456635f, 22.650377f, 82.507996f, 20.417046f, 84.01137f, 14.920707f)
    p.curveTo(84.63673f, 12.634447f, 84.855675f, 8.916157f, 84.49795f, 6.6578465f)
    p.lineTo(83.84752f, 2.5518265f)
    p.lineTo(103.20885f, 2.8435364f)
    p.curveTo(115.333595f, 3.0262263f, 122.51948f, 3.5351863f, 122.43457f, 4.2052765f)
    p.curveTo(122.35997f, 4.7937965f, 121.98546f, 7.0549664f, 121.60228f, 9.230126f)
    p.curveTo(120.66975f, 14.523596f, 122.42551f, 15.369757f, 134.94672f, 15.661226f)
    p.lineTo(144.8301f, 15.891306f)
    p.lineTo(146.42796f, 12.496106f)
    p.curveTo(147.30678f, 10.6287565f, 148.95827f, 8.412646f, 150.09793f, 7.5714064f)
    p.curveTo(151.8605f, 6.270386f, 151.9587f, 5.7848363f, 150.75528f, 4.3210664f)
    p.curveTo(149.49657f, 2.7900562f, 149.79604f, 2.6002364f, 153.47015f, 2.6002364f)
    p.curveTo(157.21294f, 2.6002364f, 158.36705f, 3.3793063f, 165.78992f, 10.916626f)
    p.curveTo(170.2945f, 15.490646f, 173.98004f, 19.620407f, 173.98004f, 20.093866f)
    p.curveTo(173.98004f, 20.567316f, 172.4298f, 21.404726f, 170.53503f, 21.300007f)
    p.curveTo(165.04161f, 20.996397f, 164.88649f, 20.580427f, 164.88649f, 22.793026f)
    p.curveTo(164.88649f, 25.296976f, 170.15231f, 25.732185f, 176.61243f, 25.750357f)
    p.curveTo(180.5466f, 25.761356f, 180.61449f, 25.592226f, 184.56628f, 30.124207f)
    p.curveTo(186.89201f, 32.791378f, 189.27487f, 36.717968f, 189.86153f, 38.849968f)
    p.curveTo(191.09773f, 43.342567f, 191.13307f, 120.0033f, 189.92023f, 166.3147f)
    p.curveTo(189.10542f, 197.42876f, 188.19508f, 204.38184f, 184.77893f, 205.58322f)
    p.curveTo(183.795f, 205.92921f, 180.70627f, 208.11333f, 177.91508f, 210.43683f)
    p.curveTo(173.62216f, 214.01042f, 172.58644f, 214.44862f, 171.19301f, 213.28123f)
    p.curveTo(169.48805f, 211.85294f, 163.74966f, 211.54323f, 160.7217f, 212.71614f)
    p.curveTo(159.66095f, 213.12704f, 159.12262f, 214.32004f, 159.33064f, 215.79874f)
    p.curveTo(159.60881f, 217.77634f, 160.4993f, 218.30754f, 164.27057f, 218.74614f)
    p.lineTo(168.87115f, 219.28123f)
    p.lineTo(165.06555f, 224.29964f)
    p.curveTo(162.97249f, 227.05974f, 161.25998f, 229.85034f, 161.25998f, 230.50084f)
    p.curveTo(161.25998f, 232.33154f, 156.07256f, 237.13313f, 154.89111f, 236.39613f)
    p.curveTo(154.31305f, 236.03534f, 153.84004f, 234.59343f, 153.84004f, 233.19153f)
    p.curveTo(153.84004f, 230.14383f, 152.44135f, 229.07112f, 149.63821f, 229.96913f)
    p.curveTo(147.90471f, 230.52463f, 147.74147f, 231.07123f, 148.61588f, 233.39284f)
    p.curveTo(150.44328f, 238.24474f, 147.73352f, 240.78633f, 139.87166f, 241.59404f)
    p.curveTo(129.34258f, 242.67593f, 88.99509f, 243.34885f, 85.486725f, 242.50104f)
    p.lineTo(85.48676f, 242.50102f)
    p.moveTo(37.836784f, 147.98813f)
    p.curveTo(39.015797f, 145.7795f, 38.244522f, 144.62532f, 35.710552f, 144.57475f)
    p.curveTo(35.258873f, 144.56575f, 34.15333f, 142.9583f, 33.581177f, 141.43918f)
    p.curveTo(32.204414f, 137.78375f, 30.793104f, 138.40201f, 30.36796f, 142.77832f)
    p.curveTo(29.76091f, 149.02713f, 35.472225f, 152.41766f, 37.836784f, 147.98811f)
    p.lineTo(37.836784f, 147.98813f)
    p.moveTo(10.740419f, 148.16185f)
    p.curveTo(10.740419f, 146.81676f, 6.9783726f, 144.78833f, 6.1098022f, 145.66512f)
    p.curveTo(4.533888f, 147.25595f, 5.621701f, 149.19423f, 8.0904255f, 149.19423f)
    p.curveTo(9.547922f, 149.19423f, 10.740419f, 148.72964f, 10.740419f, 148.16183f)
    p.lineTo(10.740419f, 148.16185f)
    p.moveTo(147.47147f, 142.24954f)
    p.curveTo(149.23048f, 140.10999f, 151.8361f, 125.957825f, 151.05179f, 122.80329f)
    p.curveTo(150.69704f, 121.37649f, 151.0958f, 119.24929f, 151.97318f, 117.888084f)
    p.curveTo(152.82393f, 116.568214f, 153.82675f, 113.32152f, 154.20166f, 110.673195f)
    p.curveTo(154.57658f, 108.024864f, 155.1604f, 104.41353f, 155.499f, 102.64797f)
    p.curveTo(156.02812f, 99.88904f, 155.65686f, 99.1662f, 152.85735f, 97.50483f)
    p.curveTo(150.08447f, 95.85927f, 149.60005f, 94.93634f, 149.60005f, 91.29902f)
    p.curveTo(149.60005f, 88.94902f, 150.27068f, 85.71715f, 151.09032f, 84.11712f)
    p.curveTo(152.3707f, 81.61773f, 152.3707f, 80.91819f, 151.09032f, 79.15061f)
    p.curveTo(149.13124f, 76.44603f, 149.18951f, 71.688095f, 151.2024f, 70.00174f)
    p.curveTo(152.08368f, 69.26341f, 153.72635f, 66.55613f, 154.85277f, 63.98555f)
    p.curveTo(156.59259f, 60.0152f, 157.36398f, 59.31178f, 159.97823f, 59.31178f)
    p.curveTo(161.6708f, 59.31178f, 164.15561f, 60.27481f, 165.5f, 61.45184f)
    p.curveTo(168.8897f, 64.41953f, 170.90068f, 63.61921f, 175.1144f, 59.36562f)
    p.curveTo(178.60358f, 55.84342f, 178.30948f, 55.90517f, 178.00696f, 49.51278f)
    p.curveTo(177.72911f, 43.64207f, 177.40298f, 42.74327f, 175.36633f, 42.23555f)
    p.curveTo(174.08835f, 41.91696f, 171.65399f, 39.56258f, 169.95668f, 37.00357f)
    p.curveTo(165.87552f, 30.85051f, 155.9755f, 25.38442f, 144.23627f, 22.67708f)
    p.curveTo(141.97824f, 22.15632f, 140.0094f, 22.67008f, 135.89436f, 25.65413f)
    p.curveTo(132.99533f, 27.756601f, 130.36284f, 30.3055f, 130.04437f, 31.31834f)
    p.curveTo(129.72592f, 32.331192f, 128.03319f, 33.70559f, 126.28273f, 34.37257f)
    p.curveTo(123.71918f, 35.34936f, 123.10009f, 36.21025f, 123.10009f, 38.79837f)
    p.curveTo(123.10009f, 41.26629f, 122.12109f, 42.79422f, 118.87891f, 45.38637f)
    p.curveTo(116.55724f, 47.24256f, 114.14624f, 48.44215f, 113.521095f, 48.052143f)
    p.curveTo(112.89594f, 47.662125f, 109.77061f, 43.294815f, 106.575874f, 38.346992f)
    p.curveTo(103.38114f, 33.39918f, 100.30667f, 29.350971f, 99.74371f, 29.350971f)
    p.curveTo(98.349495f, 29.350971f, 98.453835f, 35.160572f, 99.93785f, 40.16067f)
    p.curveTo(101.474655f, 45.33861f, 99.94425f, 47.73505f, 95.65333f, 46.86879f)
    p.curveTo(91.95812f, 46.12275f, 89.38829f, 48.70579f, 91.80847f, 50.73338f)
    p.curveTo(93.94722f, 52.52518f, 102.49312f, 53.02726f, 107.73012f, 51.668777f)
    p.curveTo(113.449005f, 50.1853f, 114.25407f, 50.24962f, 120.98009f, 52.727306f)
    p.curveTo(124.281746f, 53.943558f, 126.96239f, 55.624268f, 127.161285f, 56.602818f)
    p.curveTo(127.494995f, 58.24466f, 128.55475f, 58.220688f, 133.20047f, 56.466267f)
    p.curveTo(135.79054f, 55.488136f, 138.07594f, 59.212757f, 140.07645f, 67.672295f)
    p.curveTo(142.79887f, 79.18465f, 142.7328f, 80.88561f, 139.4422f, 84.00345f)
    p.curveTo(136.95296f, 86.36198f, 136.76694f, 87.10411f, 137.39372f, 92.17668f)
    p.curveTo(138.054f, 97.520485f, 137.9683f, 97.78491f, 135.36215f, 98.4452f)
    p.curveTo(133.46951f, 98.92472f, 132.36932f, 100.15796f, 131.74806f, 102.49631f)
    p.curveTo(130.62735f, 106.85358f, 134.61754f, 114.37829f, 137.64543f, 116.87073f)
    p.curveTo(137.64543f, 116.87073f, 140.86018f, 118.53934f, 141.5908f, 120.065765f)
    p.curveTo(143.15338f, 123.33041f, 141.6205f, 130.92369f, 141.6205f, 130.92369f)
    p.curveTo(141.6436f, 139.38704f, 142.00078f, 142.00545f, 143.24011f, 142.79648f)
    p.curveTo(145.39886f, 144.17435f, 145.9473f, 144.10345f, 147.47147f, 142.24954f)
    p.lineTo(147.47147f, 142.24954f)
    p.moveTo(9.978853f, 139.29646f)
    p.curveTo(10.744494f, 137.14096f, 8.719759f, 134.21382f, 6.4631352f, 134.21382f)
    p.curveTo(4.1361556f, 134.21382f, 3.847318f, 135.489f, 5.477728f, 138.56429f)
    p.curveTo(6.716656f, 140.90115f, 9.261806f, 141.31516f, 9.978853f, 139.29646f)
    p.lineTo(9.978853f, 139.29646f)
    p.moveTo(53.55691f, 120.75095f)
    p.curveTo(54.540146f, 118.16444f, 54.322376f, 110.673195f, 53.26395f, 110.673195f)
    p.curveTo(52.075253f, 110.673195f, 51.053493f, 114.47426f, 51.0348f, 118.96591f)
    p.curveTo(51.01961f, 122.616394f, 52.4602f, 123.63598f, 53.556915f, 120.75095f)
    p.lineTo(53.55691f, 120.75095f)
    p.moveTo(53.65609f, 100.37724f)
    p.curveTo(55.067883f, 96.96636f, 55.988155f, 83.92246f, 54.817005f, 83.92246f)
    p.curveTo(54.57319f, 83.92246f, 53.680695f, 83.654015f, 52.833687f, 83.325905f)
    p.curveTo(48.66432f, 81.71082f, 46.32539f, 90.20986f, 49.430325f, 95.69279f)
    p.curveTo(50.263504f, 97.16408f, 50.9621f, 99.69202f, 50.98276f, 101.31044f)
    p.curveTo(51.033203f, 105.26121f, 51.736137f, 105.01582f, 53.65609f, 100.37725f)
    p.lineTo(53.65609f, 100.37724f)
    p.moveTo(9.602103f, 82.41268f)
    p.curveTo(10.488918f, 81.334015f, 10.512722f, 80.69661f, 9.685461f, 80.180504f)
    p.curveTo(8.279438f, 79.30331f, 5.229894f, 81.642876f, 6.04466f, 82.97367f)
    p.curveTo(6.884706f, 84.34575f, 8.180879f, 84.14135f, 9.602102f, 82.41268f)
    p.lineTo(9.602103f, 82.41268f)
    p.moveTo(48.648705f, 160.86076f)
    p.curveTo(48.657604f, 159.49567f, 49.18756f, 157.41962f, 49.717197f, 156.57468f)
    p.curveTo(50.52822f, 155.28085f, 51.39832f, 155.53392f, 52.84854f, 156.7489f)
    p.curveTo(55.274105f, 158.78098f, 54.39764f, 162.93736f, 51.463894f, 163.35796f)
    p.curveTo(49.575233f, 163.62872f, 48.63585f, 162.82623f, 48.648705f, 160.86075f)
    p.lineTo(48.648705f, 160.86076f)
    p.moveTo(25.85253f, 12.498009f)
    p.curveTo(28.86951f, 9.4082985f, 31.515423f, 6.8803487f, 31.732332f, 6.8803487f)
    p.curveTo(32.49744f, 6.8803487f, 30.626753f, 15.993019f, 29.597271f, 17.280869f)
    p.curveTo(29.0234f, 17.998758f, 26.711845f, 18.480268f, 24.460487f, 18.350899f)
    p.lineTo(20.367107f, 18.115658f)
    p.lineTo(25.85253f, 12.498009f)
    p.moveTo(34.005047f, 4.272559f)
    p.curveTo(34.81448f, 3.2880292f, 36.96139f, 2.628129f, 39.225143f, 2.6680691f)
    p.curveTo(43.33851f, 2.740569f, 42.1275f, 3.612229f, 35.730247f, 5.183469f)
    p.curveTo(33.001194f, 5.853759f, 32.794704f, 5.744729f, 34.005043f, 4.2725587f)
    p.lineTo(34.005047f, 4.272559f)
  }

  private def mkPath7(p: Path2D): Unit = {
    p.moveTo(101.89581f, 240.04272f)
    p.curveTo(90.40885f, 239.38353f, 86.0188f, 237.97572f, 82.6045f, 233.85672f)
    p.curveTo(80.890274f, 231.78851f, 80.92711f, 231.44542f, 83.331245f, 227.08472f)
    p.curveTo(84.72412f, 224.55821f, 86.64824f, 220.14651f, 87.60706f, 217.28061f)
    p.lineTo(89.35038f, 212.07f)
    p.lineTo(85.87538f, 208.4508f)
    p.curveTo(83.29419f, 205.76251f, 82.708176f, 204.5209f, 83.597015f, 203.62363f)
    p.curveTo(84.37638f, 202.83688f, 84.58517f, 199.90535f, 84.19578f, 195.21669f)
    p.curveTo(83.86694f, 191.25726f, 84.01918f, 187.75787f, 84.53408f, 187.44028f)
    p.curveTo(85.04898f, 187.12268f, 95.78691f, 186.51149f, 108.39615f, 186.08206f)
    p.lineTo(131.32204f, 185.3013f)
    p.lineTo(134.34648f, 188.72787f)
    p.curveTo(136.43198f, 191.09062f, 137.27527f, 193.07527f, 137.06276f, 195.12042f)
    p.curveTo(136.83119f, 197.34897f, 137.45709f, 198.55106f, 139.58017f, 199.95532f)
    p.curveTo(141.82619f, 201.44089f, 142.28844f, 202.41652f, 141.83371f, 204.71161f)
    p.curveTo(140.86453f, 209.6033f, 144.40326f, 215.8455f, 149.4473f, 218.1416f)
    p.curveTo(153.67436f, 220.0657f, 153.92625f, 220.0691f, 155.94043f, 218.2296f)
    p.curveTo(157.85034f, 216.4848f, 158.09483f, 216.4703f, 158.7014f, 218.066f)
    p.curveTo(159.10536f, 219.1287f, 160.57208f, 219.8167f, 162.43349f, 219.8167f)
    p.curveTo(166.37439f, 219.8167f, 166.29584f, 220.7583f, 162.00462f, 224.9569f)
    p.curveTo(159.21747f, 227.6839f, 157.6205f, 228.37689f, 154.12364f, 228.37689f)
    p.curveTo(148.2111f, 228.37689f, 144.30013f, 230.00429f, 144.30013f, 232.4646f)
    p.curveTo(144.30013f, 235.7768f, 140.98996f, 237.7036f, 133.17015f, 238.9431f)
    p.curveTo(123.1918f, 240.5248f, 115.19094f, 240.8063f, 101.89583f, 240.0432f)
    p.lineTo(101.89581f, 240.04272f)
    p.moveTo(27.729683f, 225.73703f)
    p.curveTo(26.21533f, 223.89503f, 23.460394f, 223.52673f, 23.460394f, 225.16634f)
    p.curveTo(23.460394f, 229.24704f, 9.92668f, 219.79033f, 5.990057f, 212.95903f)
    p.curveTo(2.3163037f, 206.58383f, 1.0290809f, 189.06213f, 2.0130885f, 158.82451f)
    p.lineTo(2.7965708f, 134.74884f)
    p.lineTo(4.7320127f, 138.33632f)
    p.curveTo(6.3447924f, 141.32571f, 6.459797f, 142.42989f, 5.4218483f, 144.95941f)
    p.curveTo(4.7367644f, 146.629f, 4.453637f, 148.44812f, 4.792675f, 149.00188f)
    p.curveTo(5.8817196f, 150.78065f, 10.66077f, 151.11543f, 11.984257f, 149.50563f)
    p.curveTo(12.995508f, 148.2756f, 12.663791f, 147.5113f, 10.289156f, 145.5999f)
    p.curveTo(7.632845f, 143.46179f, 7.5074306f, 143.08049f, 9.038591f, 141.79771f)
    p.curveTo(11.594882f, 139.6561f, 11.098244f, 136.69221f, 7.6657867f, 133.60493f)
    p.curveTo(5.897973f, 132.01492f, 4.11523f, 128.9316f, 3.4714372f, 126.35067f)
    p.curveTo(1.9893202f, 120.40894f, 1.9143996f, 38.42321f, 3.3885453f, 35.64267f)
    p.curveTo(4.5969615f, 33.36336f, 6.497431f, 32.952488f, 6.5063415f, 34.96862f)
    p.curveTo(6.5311775f, 40.58778f, 8.952351f, 44.38262f, 15.540464f, 49.1283f)
    p.curveTo(19.313425f, 51.84611f, 22.400393f, 54.70874f, 22.400393f, 55.48973f)
    p.curveTo(22.400393f, 58.241222f, 19.165691f, 59.67577f, 13.484658f, 59.44376f)
    p.curveTo(8.509733f, 59.24059f, 7.665347f, 59.52586f, 6.0995264f, 61.93814f)
    p.curveTo(4.0085945f, 65.29455f, 7.762039f, 66.24732f, 8.752139f, 69.5362f)
    p.curveTo(9.88738f, 73.41741f, 10.574235f, 74.305855f, 12.123431f, 73.89688f)
    p.curveTo(13.551704f, 73.51985f, 14.822271f, 74.64216f, 16.901987f, 78.11786f)
    p.curveTo(19.29331f, 82.11432f, 20.256907f, 82.85243f, 23.08297f, 82.85243f)
    p.curveTo(25.789972f, 82.85243f, 26.852928f, 83.57434f, 28.634838f, 86.62304f)
    p.curveTo(29.846962f, 88.69687f, 31.538298f, 90.66466f, 32.393364f, 90.99588f)
    p.curveTo(34.733364f, 91.90232f, 38.789402f, 88.3352f, 42.60868f, 82.01194f)
    p.curveTo(44.487488f, 78.90136f, 46.552464f, 76.53151f, 47.197517f, 76.74561f)
    p.curveTo(48.81974f, 77.284065f, 49.330402f, 81.776276f, 47.930084f, 83.18984f)
    p.curveTo(46.2746f, 84.86099f, 46.5157f, 90.84203f, 48.42444f, 95.45352f)
    p.curveTo(49.575615f, 98.23474f, 50.072845f, 103.03656f, 50.082905f, 111.46959f)
    p.curveTo(50.096207f, 122.619896f, 50.247993f, 123.51354f, 52.128605f, 123.51354f)
    p.curveTo(54.79444f, 123.51354f, 55.351013f, 120.86946f, 55.169323f, 109.068146f)
    p.curveTo(55.087784f, 103.77151f, 55.36311f, 95.75453f, 55.78117f, 91.25266f)
    p.curveTo(56.487778f, 83.64359f, 56.39148f, 83.01944f, 54.413094f, 82.38558f)
    p.curveTo(52.04227f, 81.62599f, 48.439423f, 74.908035f, 49.253864f, 72.76554f)
    p.curveTo(49.541733f, 72.00826f, 51.6072f, 71.104034f, 53.843792f, 70.75614f)
    p.curveTo(56.080383f, 70.408264f, 58.961937f, 69.80731f, 60.247246f, 69.420715f)
    p.curveTo(62.125134f, 68.8559f, 62.681225f, 69.212776f, 63.078262f, 71.23752f)
    p.curveTo(63.350014f, 72.62333f, 64.20639f, 77.079315f, 64.98133f, 81.139694f)
    p.curveTo(66.75142f, 90.41437f, 68.72546f, 92.07268f, 73.03473f, 87.905045f)
    p.curveTo(76.12809f, 84.91338f, 80.82922f, 84.092445f, 83.844284f, 86.017426f)
    p.curveTo(85.740326f, 87.22797f, 92.725006f, 83.54788f, 94.90453f, 80.19003f)
    p.curveTo(95.71047f, 78.94837f, 97.425644f, 74.134346f, 98.71602f, 69.4922f)
    p.curveTo(100.96295f, 61.408813f, 100.98167f, 60.992523f, 99.1586f, 59.646843f)
    p.curveTo(98.11164f, 58.874054f, 95.96624f, 58.241764f, 94.39105f, 58.241764f)
    p.curveTo(92.71522f, 58.241764f, 91.250496f, 57.514214f, 90.86041f, 56.488052f)
    p.curveTo(90.28302f, 54.969162f, 90.83009f, 54.82239f, 94.946175f, 55.391903f)
    p.curveTo(98.05565f, 55.822144f, 100.720436f, 55.540012f, 102.654396f, 54.5758f)
    p.curveTo(112.667076f, 49.583862f, 112.88307f, 49.55984f, 119.84158f, 52.664413f)
    p.curveTo(123.382805f, 54.244343f, 126.28017f, 55.987293f, 126.28017f, 56.537632f)
    p.curveTo(126.28017f, 57.08795f, 125.49074f, 58.418793f, 124.52588f, 59.49504f)
    p.curveTo(122.9329f, 61.27193f, 122.92832f, 61.45184f, 124.47598f, 61.45184f)
    p.curveTo(125.41341f, 61.45184f, 127.393394f, 60.89393f, 128.87595f, 60.21204f)
    p.curveTo(132.60423f, 58.49725f, 135.50917f, 61.30321f, 136.43121f, 67.50986f)
    p.curveTo(137.47282f, 74.52153f, 134.46492f, 89.43716f, 130.78482f, 95.50932f)
    p.lineTo(127.75538f, 100.507904f)
    p.lineTo(128.39323f, 114.41828f)
    p.curveTo(128.77501f, 122.74436f, 128.61032f, 129.32407f, 127.98299f, 130.80823f)
    p.curveTo(126.54522f, 134.20963f, 129.88002f, 140.44485f, 133.61557f, 141.33975f)
    p.curveTo(135.11958f, 141.70006f, 137.54263f, 142.6139f, 139.00012f, 143.37056f)
    p.curveTo(140.45763f, 144.1272f, 142.48488f, 145.00967f, 143.50511f, 145.33163f)
    p.curveTo(145.69698f, 146.0233f, 145.94444f, 150.61862f, 144.22556f, 158.70938f)
    p.curveTo(143.4271f, 162.46771f, 142.6666f, 163.88533f, 141.6584f, 163.49478f)
    p.curveTo(140.87047f, 163.18956f, 139.26575f, 163.45848f, 138.09238f, 164.0924f)
    p.curveTo(136.60838f, 164.89413f, 135.08641f, 164.91011f, 133.09256f, 164.1448f)
    p.curveTo(129.1887f, 162.64653f, 128.80801f, 163.44548f, 131.4453f, 167.60179f)
    p.curveTo(135.81729f, 174.49197f, 137.1824f, 178.30278f, 135.63368f, 179.29398f)
    p.curveTo(134.86172f, 179.78802f, 128.12473f, 180.19963f, 120.662544f, 180.20865f)
    p.curveTo(110.323616f, 180.22115f, 106.32125f, 179.82115f, 103.843765f, 178.52788f)
    p.curveTo(102.055626f, 177.59444f, 99.63543f, 177.0834f, 98.46556f, 177.39221f)
    p.curveTo(97.22826f, 177.71883f, 94.95222f, 176.97559f, 93.02439f, 175.61539f)
    p.curveTo(91.20162f, 174.32932f, 89.49683f, 173.14024f, 89.235985f, 172.97302f)
    p.curveTo(88.97513f, 172.80579f, 89.5529f, 171.31691f, 90.51993f, 169.66437f)
    p.curveTo(92.922134f, 165.55928f, 91.29421f, 164.1746f, 84.06577f, 164.1746f)
    p.curveTo(77.76756f, 164.1746f, 77.86235f, 163.97389f, 80.22631f, 172.3049f)
    p.curveTo(80.81269f, 174.37138f, 80.32966f, 174.60403f, 74.15685f, 175.2286f)
    p.curveTo(70.468254f, 175.60179f, 66.37707f, 176.21255f, 65.065315f, 176.58585f)
    p.curveTo(61.369907f, 177.63745f, 62.037926f, 174.23932f, 66.39031f, 169.84575f)
    p.curveTo(68.43081f, 167.78595f, 70.1003f, 165.98172f, 70.1003f, 165.83636f)
    p.curveTo(70.1003f, 165.69101f, 69.14631f, 164.4617f, 67.98031f, 163.10457f)
    p.curveTo(64.16614f, 158.66518f, 65.32955f, 154.93243f, 71.95277f, 150.3591f)
    p.curveTo(73.84612f, 149.05173f, 75.660576f, 146.91486f, 75.98488f, 145.61047f)
    p.curveTo(76.7456f, 142.55086f, 74.66405f, 129.35791f, 72.99489f, 126.6599f)
    p.curveTo(71.96968f, 125.00272f, 72.01321f, 124.097435f, 73.21046f, 122.17596f)
    p.curveTo(75.01741f, 119.27597f, 75.67571f, 109.431526f, 74.40898f, 104.25297f)
    p.curveTo(73.90512f, 102.19317f, 73.19746f, 99.18371f, 72.83639f, 97.565285f)
    p.curveTo(72.47532f, 95.94686f, 71.53417f, 94.6227f, 70.74496f, 94.6227f)
    p.curveTo(68.9095f, 94.6227f, 68.0376f, 101.488075f, 67.480644f, 120.32608f)
    p.curveTo(67.14159f, 131.79417f, 66.60737f, 135.84335f, 64.90427f, 139.85413f)
    p.curveTo(63.722527f, 142.6371f, 62.05782f, 144.91408f, 61.204918f, 144.91408f)
    p.curveTo(58.886974f, 144.91408f, 55.260326f, 139.68527f, 55.260326f, 136.34329f)
    p.curveTo(55.260326f, 131.29749f, 53.991253f, 126.72357f, 52.59124f, 126.72357f)
    p.curveTo(50.821415f, 126.72357f, 49.96034f, 129.17506f, 49.96034f, 134.21378f)
    p.curveTo(49.96034f, 141.20801f, 49.434032f, 141.70398f, 42.01186f, 141.70398f)
    p.curveTo(35.74412f, 141.70398f, 35.309822f, 141.5416f, 34.66741f, 138.95782f)
    p.curveTo(33.354973f, 133.67915f, 28.240936f, 137.92345f, 27.449486f, 144.94818f)
    p.curveTo(27.248f, 146.73651f, 28.171967f, 148.11765f, 30.772137f, 149.91483f)
    p.curveTo(35.271328f, 153.02458f, 35.721752f, 153.01407f, 38.737526f, 149.7292f)
    p.curveTo(41.686565f, 146.51709f, 42.540405f, 146.37848f, 42.540405f, 149.11188f)
    p.curveTo(42.540405f, 150.24364f, 41.163395f, 152.55966f, 39.48038f, 154.2586f)
    p.curveTo(37.797367f, 155.95755f, 35.216175f, 159.72632f, 33.7444f, 162.63365f)
    p.curveTo(30.256023f, 169.52454f, 27.16207f, 172.73483f, 24.009266f, 172.73483f)
    p.curveTo(20.2989f, 172.73483f, 18.160465f, 176.53851f, 18.160465f, 183.1382f)
    p.curveTo(18.160465f, 187.2291f, 17.756937f, 188.78526f, 16.69612f, 188.78526f)
    p.curveTo(15.890729f, 188.78526f, 14.519053f, 190.97066f, 13.64795f, 193.64172f)
    p.curveTo(12.0685f, 198.48479f, 12.071809f, 198.50224f, 14.847298f, 199.96254f)
    p.curveTo(19.816975f, 202.57729f, 26.54837f, 209.7037f, 28.711697f, 214.64061f)
    p.curveTo(32.31802f, 222.8704f, 31.643127f, 230.49692f, 27.729744f, 225.73701f)
    p.lineTo(27.729683f, 225.73703f)
    p.moveTo(9.861957f, 83.2216f)
    p.curveTo(12.391275f, 80.910934f, 12.338047f, 78.57231f, 9.756137f, 78.57231f)
    p.curveTo(7.7323904f, 78.57231f, 4.380435f, 81.17759f, 4.380435f, 82.75052f)
    p.curveTo(4.380435f, 85.36775f, 7.243396f, 85.61379f, 9.861957f, 83.221596f)
    p.lineTo(9.861957f, 83.2216f)
    p.moveTo(171.01204f, 212.11192f)
    p.curveTo(169.2921f, 210.37572f, 169.34418f, 210.05292f, 172.45012f, 203.19841f)
    p.curveTo(174.752f, 198.11836f, 175.86958f, 196.91055f, 179.8701f, 195.1795f)
    p.curveTo(182.46054f, 194.0586f, 184.58002f, 192.59843f, 184.58002f, 191.93471f)
    p.curveTo(184.58002f, 191.27097f, 185.52748f, 189.51201f, 186.6855f, 188.0259f)
    p.curveTo(188.57603f, 185.59972f, 188.86456f, 185.51741f, 189.51163f, 187.2196f)
    p.curveTo(191.1395f, 191.5019f, 187.9178f, 198.28615f, 180.62895f, 205.92473f)
    p.curveTo(176.70793f, 210.03394f, 173.22626f, 213.39603f, 172.89194f, 213.39603f)
    p.curveTo(172.5576f, 213.39603f, 171.71165f, 212.81822f, 171.01205f, 212.11192f)
    p.lineTo(171.01204f, 212.11192f)
    p.moveTo(71.4485f, 206.21822f)
    p.curveTo(70.25137f, 205.16362f, 68.99321f, 202.73581f, 68.65259f, 200.82315f)
    p.curveTo(68.08991f, 197.6635f, 68.274574f, 197.34555f, 70.67236f, 197.34555f)
    p.curveTo(73.51076f, 197.34555f, 77.794495f, 202.90889f, 77.254234f, 205.89352f)
    p.curveTo(76.82861f, 208.24472f, 73.93271f, 208.40672f, 71.4485f, 206.21823f)
    p.lineTo(71.4485f, 206.21822f)
    p.moveTo(48.937626f, 176.0153f)
    p.curveTo(47.11071f, 172.56938f, 47.616478f, 170.59482f, 50.32604f, 170.59482f)
    p.curveTo(52.825092f, 170.59482f, 56.320312f, 173.53482f, 56.320312f, 175.63692f)
    p.curveTo(56.320312f, 176.61212f, 53.1093f, 178.02574f, 50.79262f, 178.07042f)
    p.curveTo(50.375885f, 178.07942f, 49.541138f, 177.15366f, 48.937626f, 176.0153f)
    p.lineTo(48.937626f, 176.0153f)
    p.moveTo(187.76f, 176.90196f)
    p.curveTo(187.76f, 176.25127f, 186.56737f, 174.2881f, 185.1097f, 172.53937f)
    p.curveTo(183.65204f, 170.79065f, 182.15991f, 168.15536f, 181.79388f, 166.6832f)
    p.curveTo(180.75058f, 162.48698f, 175.58649f, 157.36063f, 173.0715f, 158.02454f)
    p.curveTo(170.08945f, 158.81172f, 169.89978f, 157.52856f, 171.29173f, 145.98416f)
    p.curveTo(172.98492f, 131.9414f, 172.59953f, 102.08483f, 170.62962f, 94.69001f)
    p.curveTo(168.78131f, 87.75167f, 167.07535f, 86.69931f, 166.10863f, 91.90112f)
    p.curveTo(164.41133f, 101.0341f, 157.55006f, 92.92208f, 157.55006f, 81.78241f)
    p.curveTo(157.55006f, 76.3658f, 157.36766f, 75.92262f, 155.25897f, 76.21596f)
    p.curveTo(152.50732f, 76.59874f, 151.34367f, 75.03499f, 152.24557f, 72.166435f)
    p.curveTo(153.00414f, 69.75384f, 158.53647f, 67.95928f, 164.97005f, 68.038956f)
    p.curveTo(171.31912f, 68.11765f, 171.86003f, 67.994255f, 171.86003f, 66.46718f)
    p.curveTo(171.86003f, 65.69451f, 173.24045f, 63.72728f, 174.92764f, 62.095547f)
    p.curveTo(178.47939f, 58.660576f, 180.64189f, 51.951805f, 180.15195f, 45.8882f)
    p.curveTo(179.86214f, 42.30146f, 179.40602f, 41.5999f, 177.16002f, 41.286278f)
    p.curveTo(171.53178f, 40.500366f, 169.78201f, 35.445686f, 174.51003f, 33.63109f)
    p.curveTo(175.96753f, 33.07172f, 177.16002f, 32.374798f, 177.16002f, 32.082428f)
    p.curveTo(177.16002f, 31.790037f, 174.53651f, 30.780928f, 171.33003f, 29.839958f)
    p.curveTo(164.78278f, 27.918598f, 163.57445f, 26.615469f, 169.19368f, 27.535969f)
    p.curveTo(171.22517f, 27.86876f, 174.43933f, 27.691698f, 176.33626f, 27.142529f)
    p.curveTo(179.54466f, 26.21366f, 180.10803f, 26.469868f, 184.41322f, 30.815819f)
    p.curveTo(187.86322f, 34.29847f, 189.25029f, 36.68124f, 189.86256f, 40.17701f)
    p.curveTo(191.7585f, 51.0017f, 190.65529f, 178.08505f, 188.66537f, 178.08505f)
    p.curveTo(188.16742f, 178.08505f, 187.76f, 177.55266f, 187.76f, 176.90198f)
    p.lineTo(187.76f, 176.90196f)
    p.moveTo(110.96413f, 45.032898f)
    p.curveTo(109.47696f, 43.06466f, 108.260185f, 40.842636f, 108.260185f, 40.09507f)
    p.curveTo(108.260185f, 39.34748f, 106.98596f, 36.3725f, 105.42859f, 33.484f)
    p.lineTo(102.59697f, 28.23217f)
    p.lineTo(104.89859f, 24.098259f)
    p.curveTo(108.42424f, 17.765839f, 108.03243f, 16.450958f, 102.6952f, 16.70401f)
    p.curveTo(100.21746f, 16.82149f, 97.41632f, 16.55733f, 96.47045f, 16.11701f)
    p.curveTo(95.07973f, 15.46957f, 94.84604f, 15.81993f, 95.24908f, 17.94825f)
    p.curveTo(95.85043f, 21.123829f, 93.39136f, 22.24886f, 88.65023f, 20.96724f)
    p.curveTo(85.48003f, 20.11026f, 85.46929f, 20.08061f, 85.162094f, 11.336869f)
    p.lineTo(84.85395f, 2.5661097f)
    p.lineTo(99.47206f, 2.6640096f)
    p.curveTo(107.512024f, 2.7178097f, 115.57717f, 3.0079195f, 117.39462f, 3.3085694f)
    p.curveTo(120.59013f, 3.8371794f, 120.68241f, 4.0045195f, 120.193405f, 8.3841095f)
    p.curveTo(119.53136f, 14.313359f, 121.60403f, 16.510609f, 127.85915f, 16.510609f)
    p.curveTo(132.98332f, 16.510609f, 135.82011f, 17.31729f, 135.82011f, 18.774408f)
    p.curveTo(135.82011f, 19.305058f, 134.38913f, 21.733358f, 132.64012f, 24.170628f)
    p.curveTo(130.89113f, 26.607887f, 129.46013f, 29.240948f, 129.46013f, 30.021847f)
    p.curveTo(129.46013f, 31.096287f, 125.89641f, 34.159336f, 123.42127f, 35.212276f)
    p.curveTo(123.306404f, 35.261177f, 122.93335f, 36.971798f, 122.592285f, 39.013725f)
    p.curveTo(122.040115f, 42.319496f, 116.762115f, 48.491295f, 114.40912f, 48.582695f)
    p.curveTo(114.00154f, 48.598495f, 112.45129f, 47.001106f, 110.96413f, 45.032887f)
    p.lineTo(110.96413f, 45.032898f)
    p.moveTo(147.13725f, 20.037998f)
    p.curveTo(145.81894f, 19.693918f, 145.43423f, 18.967928f, 145.92722f, 17.754568f)
    p.curveTo(146.32475f, 16.776129f, 147.10498f, 14.384058f, 147.66104f, 12.438858f)
    p.curveTo(148.78374f, 8.511528f, 151.42859f, 6.832738f, 152.87082f, 9.131998f)
    p.curveTo(154.19379f, 11.241108f, 154.06001f, 14.535868f, 152.51508f, 17.893978f)
    p.curveTo(151.18567f, 20.783619f, 150.71417f, 20.971598f, 147.13725f, 20.037998f)
    p.lineTo(147.13725f, 20.037998f)
    p.moveTo(25.315386f, 17.913069f)
    p.curveTo(22.515474f, 17.17446f, 23.063812f, 15.178379f, 27.170382f, 11.160469f)
    p.lineTo(30.880373f, 7.530579f)
    p.lineTo(30.880373f, 11.409149f)
    p.curveTo(30.880373f, 13.542369f, 30.130804f, 16.04439f, 29.214663f, 16.9692f)
    p.curveTo(27.737724f, 18.77807f, 27.070698f, 18.37828f, 25.315386f, 17.91307f)
    p.lineTo(25.315386f, 17.913069f)
    p.moveTo(35.65036f, 3.670269f)
    p.curveTo(36.010674f, 3.081749f, 36.782475f, 2.600239f, 37.36547f, 2.600239f)
    p.curveTo(37.94847f, 2.600239f, 38.13067f, 3.081749f, 37.770355f, 3.670269f)
    p.curveTo(37.41004f, 4.258779f, 36.63824f, 4.740299f, 36.055244f, 4.740299f)
    p.curveTo(35.472248f, 4.740299f, 35.290047f, 4.258779f, 35.65036f, 3.6702693f)
    p.lineTo(35.65036f, 3.670269f)
  }

  private def mkPath8(p: Path2D): Unit = {
    p.moveTo(103.4902f, 232.68352f)
    p.curveTo(99.9922f, 231.58582f, 94.74522f, 230.64182f, 91.83022f, 230.58572f)
    p.curveTo(83.26359f, 230.42082f, 82.80142f, 229.47823f, 87.92694f, 222.62532f)
    p.curveTo(91.504684f, 217.84172f, 93.12001f, 216.56493f, 96.33296f, 215.98042f)
    p.curveTo(101.75699f, 214.99382f, 103.142044f, 213.62352f, 102.79735f, 209.58482f)
    p.curveTo(102.63589f, 207.69302f, 103.17205f, 205.33232f, 103.988815f, 204.33893f)
    p.curveTo(105.2641f, 202.78775f, 105.25889f, 202.38939f, 103.95202f, 201.51878f)
    p.curveTo(103.115005f, 200.9612f, 101.26792f, 200.70755f, 99.847374f, 200.95511f)
    p.curveTo(96.23552f, 201.5846f, 94.480194f, 200.68457f, 94.480194f, 198.20312f)
    p.curveTo(94.480194f, 196.2465f, 94.98962f, 196.13014f, 100.960884f, 196.72275f)
    p.curveTo(111.491714f, 197.76788f, 121.38101f, 200.66827f, 131.58011f, 205.70291f)
    p.curveTo(137.21858f, 208.48631f, 139.59435f, 211.79881f, 136.69345f, 212.83241f)
    p.curveTo(129.3175f, 215.46062f, 129.33731f, 215.44511f, 130.51987f, 217.67561f)
    p.curveTo(131.32549f, 219.19511f, 132.35939f, 219.66362f, 134.00752f, 219.2557f)
    p.curveTo(135.29594f, 218.93681f, 137.7811f, 218.63791f, 139.5301f, 218.5914f)
    p.curveTo(143.3439f, 218.4898f, 161.28947f, 221.628f, 162.2049f, 222.5563f)
    p.curveTo(163.60564f, 223.9767f, 157.70584f, 227.30641f, 153.78842f, 227.30641f)
    p.curveTo(148.58488f, 227.30641f, 136.41977f, 230.14851f, 132.20428f, 232.34901f)
    p.curveTo(127.16399f, 234.98012f, 111.394135f, 235.16382f, 103.4902f, 232.68352f)
    p.lineTo(103.4902f, 232.68352f)
    p.moveTo(27.851845f, 223.76051f)
    p.curveTo(27.060658f, 222.78992f, 22.012383f, 219.05782f, 16.633461f, 215.46701f)
    p.curveTo(2.4517393f, 205.99971f, 2.8599453f, 207.10141f, 2.4386587f, 177.1561f)
    p.curveTo(2.2397587f, 163.01805f, 2.5063288f, 151.72809f, 3.0520592f, 151.17722f)
    p.curveTo(3.6322956f, 150.59148f, 5.107546f, 151.06865f, 6.7510214f, 152.37364f)
    p.curveTo(8.254603f, 153.56754f, 9.837441f, 154.54439f, 10.268439f, 154.54439f)
    p.curveTo(10.699439f, 154.54439f, 13.042855f, 152.89766f, 15.476032f, 150.885f)
    p.curveTo(19.968418f, 147.16898f, 21.458525f, 147.11165f, 22.737486f, 150.60556f)
    p.curveTo(23.230085f, 151.95126f, 24.089422f, 152.34702f, 25.522184f, 151.88797f)
    p.curveTo(28.518791f, 150.92789f, 34.060364f, 154.12389f, 34.060364f, 156.81223f)
    p.curveTo(34.060364f, 158.02931f, 32.510117f, 161.65947f, 30.615372f, 164.87926f)
    p.curveTo(28.094765f, 169.1626f, 26.379519f, 170.89603f, 24.223003f, 171.33943f)
    p.curveTo(20.487837f, 172.10744f, 17.100405f, 176.39767f, 17.100405f, 180.36034f)
    p.curveTo(17.100405f, 182.25821f, 16.296682f, 183.92375f, 14.98041f, 184.75354f)
    p.curveTo(13.407018f, 185.74545f, 12.8604145f, 187.24889f, 12.8604145f, 190.58463f)
    p.curveTo(12.8604145f, 193.05666f, 12.383415f, 195.3768f, 11.800417f, 195.74054f)
    p.curveTo(9.622068f, 197.09956f, 10.860204f, 199.64536f, 14.432255f, 201.152f)
    p.curveTo(16.851042f, 202.17218f, 18.84486f, 204.13535f, 20.21432f, 206.84505f)
    p.curveTo(21.363947f, 209.11984f, 23.239244f, 211.22784f, 24.381647f, 211.52934f)
    p.curveTo(27.163527f, 212.26375f, 30.022448f, 218.09224f, 29.6175f, 222.20384f)
    p.curveTo(29.32547f, 225.16895f, 29.13605f, 225.33594f, 27.851849f, 223.76054f)
    p.lineTo(27.851845f, 223.76051f)
    p.moveTo(171.87451f, 209.91841f)
    p.curveTo(171.91661f, 206.02911f, 173.29854f, 203.76572f, 175.6311f, 203.76572f)
    p.curveTo(179.25171f, 203.76572f, 179.83028f, 205.71161f, 177.0863f, 208.66011f)
    p.curveTo(174.4876f, 211.45241f, 171.85103f, 212.089f, 171.87451f, 209.91841f)
    p.lineTo(171.87451f, 209.91841f)
    p.moveTo(178.77792f, 198.46114f)
    p.curveTo(178.43297f, 197.89769f, 179.71655f, 196.64192f, 181.63036f, 195.67055f)
    p.curveTo(183.54417f, 194.69917f, 185.9841f, 192.87299f, 187.05243f, 191.61237f)
    p.curveTo(188.99033f, 189.32565f, 188.9934f, 189.32881f, 188.37112f, 192.96344f)
    p.curveTo(188.02809f, 194.96716f, 187.21486f, 197.25433f, 186.56392f, 198.04608f)
    p.curveTo(185.20615f, 199.69759f, 179.71417f, 199.99037f, 178.77792f, 198.46114f)
    p.lineTo(178.77792f, 198.46114f)
    p.moveTo(117.06624f, 178.13454f)
    p.curveTo(116.04477f, 176.93027f, 114.44419f, 175.94496f, 113.50938f, 175.94496f)
    p.curveTo(110.90086f, 175.94496f, 107.200195f, 171.3345f, 107.200195f, 168.08469f)
    p.curveTo(107.200195f, 166.48573f, 106.60394f, 164.96272f, 105.875206f, 164.70023f)
    p.curveTo(103.741585f, 163.9317f, 90.46033f, 162.8997f, 80.49579f, 162.72818f)
    p.curveTo(70.98505f, 162.56448f, 69.37463f, 161.94214f, 69.00987f, 158.28947f)
    p.curveTo(68.61837f, 154.36905f, 69.01937f, 153.54045f, 72.077354f, 151.94391f)
    p.curveTo(73.747734f, 151.07195f, 75.846664f, 148.7724f, 76.74164f, 146.8338f)
    p.curveTo(78.864105f, 142.23637f, 78.012314f, 132.65468f, 75.11099f, 128.49075f)
    p.curveTo(73.09441f, 125.59661f, 73.07487f, 125.257225f, 74.72374f, 121.76677f)
    p.curveTo(75.678825f, 119.74497f, 76.443275f, 115.57915f, 76.422516f, 112.50941f)
    p.curveTo(76.379906f, 106.213326f, 74.03847f, 95.229195f, 72.284065f, 93.09526f)
    p.curveTo(70.480034f, 90.90096f, 75.46978f, 88.21183f, 81.45797f, 88.15116f)
    p.curveTo(84.24773f, 88.12286f, 88.01389f, 87.28024f, 89.827255f, 86.27861f)
    p.curveTo(97.51426f, 82.03255f, 102.229256f, 78.1848f, 103.32007f, 75.26755f)
    p.curveTo(103.96078f, 73.554054f, 105.002335f, 72.152115f, 105.63466f, 72.152115f)
    p.curveTo(107.18085f, 72.152115f, 113.56019f, 65.42922f, 113.56019f, 63.799786f)
    p.curveTo(113.56019f, 63.087395f, 111.628975f, 61.724495f, 109.268616f, 60.771114f)
    p.curveTo(104.40611f, 58.807125f, 104.04881f, 56.461975f, 108.269585f, 54.214073f)
    p.curveTo(111.09352f, 52.710102f, 116.45168f, 53.003365f, 121.32829f, 54.928772f)
    p.lineTo(124.32642f, 56.11251f)
    p.lineTo(122.12329f, 59.71098f)
    p.curveTo(120.91157f, 61.69014f, 119.92016f, 63.61375f, 119.92016f, 63.98567f)
    p.curveTo(119.92016f, 64.3576f, 122.015625f, 64.661896f, 124.57674f, 64.661896f)
    p.curveTo(130.1649f, 64.661896f, 130.51906f, 65.28979f, 131.21579f, 76.43221f)
    p.curveTo(131.9446f, 88.08776f, 132.00578f, 87.72746f, 128.40015f, 93.01766f)
    p.curveTo(126.57667f, 95.69309f, 125.13834f, 98.71363f, 125.20389f, 99.729996f)
    p.curveTo(126.16252f, 114.59591f, 126.27975f, 126.4738f, 125.50432f, 130.16776f)
    p.curveTo(124.928185f, 132.91228f, 124.92894f, 136.24364f, 125.50632f, 138.4775f)
    p.curveTo(126.33587f, 141.68776f, 126.16189f, 142.41258f, 124.255066f, 143.69064f)
    p.curveTo(121.462204f, 145.56258f, 121.42512f, 147.71652f, 124.16026f, 149.1942f)
    p.curveTo(125.326256f, 149.82411f, 126.28025f, 151.2856f, 126.28025f, 152.44193f)
    p.curveTo(126.28025f, 155.66383f, 129.42847f, 154.97101f, 130.09798f, 151.60176f)
    p.curveTo(130.64287f, 148.85965f, 131.07436f, 148.64517f, 136.43147f, 148.45338f)
    p.curveTo(141.24042f, 148.28122f, 142.18022f, 148.54839f, 142.18022f, 150.08784f)
    p.curveTo(142.18022f, 152.64459f, 139.20184f, 156.6844f, 137.31686f, 156.6844f)
    p.curveTo(136.45714f, 156.6844f, 135.47484f, 157.41801f, 135.13399f, 158.31465f)
    p.curveTo(134.67491f, 159.5223f, 133.60811f, 159.77328f, 131.01854f, 159.28287f)
    p.curveTo(128.1994f, 158.749f, 127.302086f, 159.03714f, 126.38251f, 160.77167f)
    p.curveTo(125.44334f, 162.54312f, 125.882065f, 163.88226f, 128.87003f, 168.36438f)
    p.curveTo(132.88954f, 174.39389f, 134.21666f, 177.65614f, 132.94836f, 178.38953f)
    p.curveTo(132.4874f, 178.65607f, 129.14323f, 179.20038f, 125.516884f, 179.59912f)
    p.curveTo(119.676384f, 180.24132f, 118.71147f, 180.07408f, 117.06633f, 178.13452f)
    p.lineTo(117.06624f, 178.13454f)
    p.moveTo(186.2096f, 171.34099f)
    p.curveTo(185.16757f, 169.73561f, 184.31502f, 167.19087f, 184.31502f, 165.68604f)
    p.curveTo(184.31502f, 163.77605f, 183.54033f, 162.65262f, 181.74922f, 161.9652f)
    p.curveTo(180.24684f, 161.38858f, 178.32715f, 159.09236f, 177.1174f, 156.42488f)
    p.lineTo(175.05138f, 151.8693f)
    p.lineTo(178.36618f, 148.99791f)
    p.curveTo(180.78102f, 146.9061f, 181.47372f, 145.5988f, 180.9176f, 144.18279f)
    p.curveTo(180.49776f, 143.11371f, 179.93915f, 139.34996f, 179.67625f, 135.81885f)
    p.curveTo(179.41336f, 132.28775f, 178.7781f, 128.19489f, 178.26459f, 126.723595f)
    p.curveTo(177.75105f, 125.252304f, 177.08188f, 118.893265f, 176.77751f, 112.59239f)
    p.curveTo(176.47314f, 106.29152f, 175.6858f, 100.12091f, 175.02791f, 98.879944f)
    p.curveTo(173.06033f, 95.1687f, 174.7838f, 77.52684f, 177.39606f, 74.63889f)
    p.curveTo(178.68895f, 73.20956f, 179.17447f, 71.77532f, 178.6535f, 70.924416f)
    p.curveTo(176.9058f, 68.06981f, 178.055f, 62.651314f, 182.05916f, 54.866547f)
    p.curveTo(184.6863f, 49.758938f, 183.92467f, 44.789646f, 179.81003f, 40.19214f)
    p.curveTo(177.76953f, 37.912178f, 176.10004f, 35.820198f, 176.10004f, 35.543297f)
    p.curveTo(176.10004f, 35.266388f, 178.10933f, 34.432137f, 180.56514f, 33.689396f)
    p.curveTo(184.85684f, 32.391407f, 185.12543f, 32.450676f, 187.48145f, 35.215626f)
    p.curveTo(194.20195f, 49.831356f, 189.83719f, 85.936714f, 189.801f, 104.076035f)
    p.curveTo(189.72859f, 140.3671f, 189.31717f, 171.00479f, 188.88675f, 172.1598f)
    p.curveTo(188.15425f, 174.12544f, 187.98293f, 174.07304f, 186.2096f, 171.34097f)
    p.lineTo(186.2096f, 171.34099f)
    p.moveTo(11.51476f, 144.26909f)
    p.curveTo(11.163314f, 143.9143f, 11.334987f, 142.40477f, 11.896254f, 140.91457f)
    p.curveTo(12.965408f, 138.07585f, 10.832918f, 133.1438f, 8.536385f, 133.1438f)
    p.curveTo(5.6940947f, 133.1438f, 3.4978209f, 123.91698f, 2.7477765f, 108.825134f)
    p.curveTo(1.9118068f, 92.00437f, 1.3085454f, 94.25956f, 8.858462f, 85.98128f)
    p.curveTo(11.309814f, 83.293434f, 16.302862f, 82.0422f, 16.935234f, 83.95726f)
    p.curveTo(17.197275f, 84.75083f, 18.694128f, 86.63256f, 20.261572f, 88.13887f)
    p.curveTo(21.829018f, 89.6452f, 24.198193f, 92.70833f, 25.526407f, 94.94583f)
    p.curveTo(27.773857f, 98.73189f, 28.245426f, 98.99162f, 32.32585f, 98.69094f)
    p.curveTo(36.142536f, 98.40969f, 36.95011f, 97.88284f, 38.56166f, 94.62275f)
    p.curveTo(39.579876f, 92.56294f, 40.891624f, 90.9258f, 41.476654f, 90.98465f)
    p.curveTo(44.187447f, 91.25735f, 44.662888f, 91.55815f, 45.81362f, 93.72867f)
    p.curveTo(46.48895f, 95.00248f, 47.460384f, 102.34556f, 47.972366f, 110.046616f)
    p.curveTo(49.12162f, 127.333336f, 49.112724f, 127.039856f, 48.704895f, 134.21382f)
    p.lineTo(48.37033f, 140.09898f)
    p.lineTo(42.574314f, 139.93434f)
    p.curveTo(39.08155f, 139.83514f, 36.60684f, 139.25046f, 36.34683f, 138.46306f)
    p.curveTo(35.57163f, 136.11545f, 31.889902f, 133.04898f, 30.721596f, 133.77788f)
    p.curveTo(30.0938f, 134.16954f, 28.65788f, 136.59468f, 27.530664f, 139.16705f)
    p.curveTo(25.23483f, 144.40628f, 22.85013f, 145.17752f, 21.340395f, 141.16902f)
    p.curveTo(19.989912f, 137.58336f, 17.629944f, 137.79385f, 15.341794f, 141.70403f)
    p.curveTo(13.44819f, 144.93997f, 12.685662f, 145.45105f, 11.51476f, 144.26909f)
    p.lineTo(11.51476f, 144.26909f)
    p.moveTo(58.17531f, 131.98805f)
    p.curveTo(55.966583f, 130.6894f, 55.65887f, 123.90691f, 57.567013f, 118.5801f)
    p.curveTo(58.544052f, 115.852585f, 58.50758f, 113.81159f, 57.398388f, 109.14421f)
    p.curveTo(56.245922f, 104.29472f, 56.231575f, 102.34351f, 57.32116f, 98.63817f)
    p.curveTo(59.022213f, 92.8534f, 60.139324f, 91.50187f, 62.667953f, 92.16938f)
    p.curveTo(64.11549f, 92.5515f, 64.70641f, 93.67072f, 64.72818f, 96.07153f)
    p.curveTo(64.74497f, 97.92302f, 64.78207f, 100.82887f, 64.81063f, 102.528984f)
    p.curveTo(64.83919f, 104.2291f, 64.07191f, 106.502014f, 63.105564f, 107.57991f)
    p.curveTo(61.464615f, 109.4103f, 61.501053f, 109.91896f, 63.657272f, 115.28181f)
    p.curveTo(66.70519f, 122.86249f, 66.7298f, 124.51579f, 63.864304f, 129.19614f)
    p.curveTo(61.244728f, 133.47481f, 60.950005f, 133.61946f, 58.17531f, 131.98805f)
    p.lineTo(58.17531f, 131.98805f)
    p.moveTo(2.2749143f, 51.01906f)
    p.curveTo(2.2900302f, 40.12101f, 2.9259572f, 35.771137f, 4.5040636f, 35.771137f)
    p.curveTo(5.0190663f, 35.771137f, 5.4404325f, 36.935596f, 5.4404325f, 38.358837f)
    p.curveTo(5.4404325f, 39.879948f, 7.423423f, 43.291656f, 10.251427f, 46.63611f)
    p.curveTo(15.92288f, 53.34327f, 16.114773f, 56.215866f, 10.962007f, 57.27343f)
    p.curveTo(9.043384f, 57.66721f, 6.6208305f, 58.76845f, 5.578554f, 59.72062f)
    p.curveTo(4.5362787f, 60.67279f, 3.3633173f, 61.45184f, 2.9719737f, 61.45184f)
    p.curveTo(2.580631f, 61.45184f, 2.2669544f, 56.757088f, 2.274915f, 51.01906f)
    p.lineTo(2.2749143f, 51.01906f)
    p.moveTo(115.68017f, 41.6563f)
    p.curveTo(114.9544f, 40.77353f, 113.45003f, 40.051258f, 112.33712f, 40.051258f)
    p.curveTo(111.22421f, 40.051258f, 110.0553f, 39.208607f, 109.73954f, 38.178707f)
    p.curveTo(109.42378f, 37.148808f, 108.72325f, 35.470047f, 108.18281f, 34.448128f)
    p.curveTo(106.89493f, 32.01288f, 106.93307f, 28.978598f, 108.26851f, 27.630518f)
    p.curveTo(108.85609f, 27.037378f, 109.949036f, 24.413137f, 110.69729f, 21.798859f)
    p.curveTo(111.64453f, 18.48935f, 112.906265f, 16.633038f, 114.85141f, 15.687219f)
    p.curveTo(117.32326f, 14.485298f, 118.08542f, 14.630459f, 121.46751f, 16.947329f)
    p.curveTo(123.56984f, 18.387508f, 125.870476f, 19.763138f, 126.58004f, 20.004278f)
    p.curveTo(127.5631f, 20.338367f, 127.57774f, 20.802448f, 126.64154f, 21.954258f)
    p.curveTo(124.77238f, 24.253998f, 120.98023f, 36.353237f, 120.98023f, 40.017498f)
    p.curveTo(120.98023f, 42.477478f, 120.499306f, 43.26135f, 118.99002f, 43.26135f)
    p.curveTo(117.89541f, 43.26135f, 116.40601f, 42.539078f, 115.680244f, 41.6563f)
    p.lineTo(115.68017f, 41.6563f)
    p.moveTo(166.07422f, 17.87015f)
    p.curveTo(159.04837f, 15.79836f, 159.94748f, 12.20727f, 156.49007f, 8.384279f)
    p.curveTo(153.36887f, 4.984579f, 153.14702f, 3.669609f, 155.69507f, 3.6720195f)
    p.curveTo(156.71532f, 3.6729796f, 160.85747f, 7.0435796f, 164.89984f, 11.16223f)
    p.curveTo(172.12326f, 18.52193f, 172.28812f, 19.4635f, 166.07422f, 17.87015f)
    p.lineTo(166.07422f, 17.87015f)
    p.moveTo(24.520388f, 15.701529f)
    p.curveTo(24.520388f, 15.174659f, 25.754547f, 13.576268f, 27.262962f, 12.149508f)
    p.lineTo(30.005537f, 9.5554285f)
    p.lineTo(29.647959f, 12.765509f)
    p.curveTo(29.383183f, 15.1424885f, 28.671398f, 16.064339f, 26.905384f, 16.317528f)
    p.curveTo(25.593637f, 16.505589f, 24.52039f, 16.228428f, 24.52039f, 15.701528f)
    p.lineTo(24.520388f, 15.701529f)
    p.moveTo(86.64365f, 11.607969f)
    p.curveTo(86.28977f, 10.677059f, 86.000244f, 8.510249f, 86.000244f, 6.792839f)
    p.lineTo(86.000244f, 3.670269f)
    p.lineTo(101.97061f, 3.670269f)
    p.lineTo(117.94098f, 3.670269f)
    p.lineTo(117.60557f, 6.612849f)
    p.curveTo(117.28627f, 9.414179f, 116.965706f, 9.571189f, 110.92702f, 9.883809f)
    p.curveTo(107.29924f, 10.071619f, 103.85744f, 10.875809f, 102.88694f, 11.762429f)
    p.curveTo(101.4026f, 13.118429f, 100.76195f, 13.097099f, 97.77339f, 11.592099f)
    p.curveTo(94.63929f, 10.013809f, 94.20159f, 10.013299f, 92.48004f, 11.5861f)
    p.curveTo(90.08713f, 13.77215f, 87.47006f, 13.78198f, 86.643654f, 11.608f)
    p.lineTo(86.64365f, 11.607969f)
  }
}