/*
 *  BasicTool.scala
 *  (Mellite)
 *
 *  Copyright (c) 2012-2022 Hanns Holger Rutz. All rights reserved.
 *
 *  This software is published under the GNU Affero General Public License v3+
 *
 *
 *  For further information, please contact Hanns Holger Rutz at
 *  contact@sciss.de
 */

package de.sciss.mellite

import de.sciss.lucre.edit.UndoManager
import de.sciss.lucre.{Txn => LTxn}
import de.sciss.model.Model
import de.sciss.span.Span

import java.awt
import java.awt.event.MouseEvent
import javax.swing.Icon
import scala.swing.Component

object BasicTool {
  trait Rectangular[Y] {
    def modelYOffset: Y
    def modelYExtent: Y
    def span: Span

//    def isValid: Boolean = modelYOffset >= 0
  }

  trait Update[+A]
  case object DragBegin extends Update[Nothing]
  final case class DragAdjust[A](value: A) extends Update[A]

  final case class DragRubber[Y](modelYOffset: Y, modelYExtent: Y, span: Span, isValid: Boolean)
    extends Update[Nothing] with Rectangular[Y]

  case object DragEnd    extends Update[Nothing] // (commit: AbstractCompoundEdit)
  case object DragCancel extends Update[Nothing]

  /** Direct adjustment without drag period. */
  case class Adjust[A](value: A) extends Update[A]
}
trait BasicTool[T <: LTxn[T], A] extends Model[BasicTool.Update[A]] {
  /** The mouse cursor used when the tool is active. */
  def getCursor(e: Option[MouseEvent]): awt.Cursor
  /** The icon to use in a tool bar. */
  def icon: Icon
  /** The human readable name of the tool. */
  def name: String

  /** Called to activate the tool to operate on the given component. */
  def install  (component: Component, e: Option[MouseEvent]): Unit
  /** Called to deactivate the tool before switching to a different tool. */
  def uninstall(component: Component): Unit

  // def handleSelect(e: MouseEvent, hitTrack: Int, pos: Long, regionOpt: Option[GraphemeProcView[T]]): Unit

  /** Called after the end of a mouse drag gesture. If this constitutes a
    * valid edit, the method should return the resulting undoable edit.
    *
    * @param drag   the last editing state
    * @return either `true` when edited or `false` if the action does not constitute an
    *         edit or the edit parameters are invalid.
    */
  def commit(drag: A)(implicit tx: T, undoManager: UndoManager[T]): Boolean
}