/*
 *  MarkdownEditorView.scala
 *  (Mellite)
 *
 *  Copyright (c) 2012-2022 Hanns Holger Rutz. All rights reserved.
 *
 *  This software is published under the GNU Affero General Public License v3+
 *
 *
 *  For further information, please contact Hanns Holger Rutz at
 *  contact@sciss.de
 */

package de.sciss.mellite

import de.sciss.lucre.edit.UndoManager
import de.sciss.lucre.swing.View
import de.sciss.lucre.{Txn, TxnLike, synth}
import de.sciss.model.Model
import de.sciss.proc.Markdown

import scala.collection.immutable.{Seq => ISeq}
import scala.swing.Action

object MarkdownEditorView {
  private[mellite] var peer: Companion = _

  private def companion: Companion = {
    require (peer != null, "Companion not yet installed")
    peer
  }

  private[mellite] trait Companion {
    def apply[T <: synth.Txn[T]](obj: Markdown[T], showEditor: Boolean, bottom: ISeq[View[T]])
                                (implicit tx: T, handler: UniverseHandler[T],
                            undoManager: UndoManager[T]): MarkdownEditorView[T]
  }

  def apply[T <: synth.Txn[T]](obj: Markdown[T], showEditor: Boolean = true, bottom: ISeq[View[T]] = Nil)
                              (implicit tx: T, handler: UniverseHandler[T],
                         undoManager: UndoManager[T]): MarkdownEditorView[T] =
    companion(obj, showEditor = showEditor, bottom = bottom)

  sealed trait Update
  final case class DirtyChange(value: Boolean) extends Update
}
trait MarkdownEditorView[T <: Txn[T]] extends UniverseObjView[T] with Model[MarkdownEditorView.Update] {
  def renderer: MarkdownRenderView[T]

  override def obj(implicit tx: T): Markdown[T]

  def dirty(implicit tx: TxnLike): Boolean

  def save(): Unit

  def undoAction: Action
  def redoAction: Action
}